{% load humanize %}
<table class="data-source chart-data table table-striped table-condensed">
  <thead>
    <tr>
      <th class="">Year</th>
      <th class="" data-tablebars=1>In-State Costs</th>
      <th class="" data-tablebars=1>Out-Of-State Costs</th>
      <th class="" data-tablebars=1>Books &amp; Supplies</th>
      <th class="span2" data-tablebars=1>Room &amp; Board</th>
    </tr>
  </thead>
  <tbody>
    {% for object in object_list %}
      <tr>
        <td data-value="{{ object.year }}">{{ object.year }}</td>
        <td class="align-right" data-value="{{ object.tuition_fees_in_state|default:'0' }}">
          ${{ object.tuition_fees_in_state|intcomma }}
        </td>
        <td data-value="{{ object.tuition_fees_outof_state|default:'0' }}">
          ${{ object.tuition_fees_outof_state|intcomma }}
        </td>
        <td data-value="{{ object.books_and_supplies|default:'0' }}">
          ${{ object.books_and_supplies|intcomma }}
        </td>
        <td data-value="{{ object.room_and_board_on_campus|default:'0' }}">
          ${{ object.room_and_board_on_campus|intcomma }}
        </td>
      </tr>
    {% endfor %}
  </tbody>
</table>
