{% load glossary %}
<p>
  <i class="icon-info-sign"></i> Data from the
  {% if object.is_private %}
    {% gloss "IPEDS" %}
    <a href="http://nces.ed.gov/ipeds/datacenter/">Data Center</a>
    and the
    {% gloss "THECB" %}
    <a href="http://www.txhighereddata.org/approot/dwprodrpt/enrmenu.htm">
      <abbr title="Profile Reports Electronically Produced">PREP</abbr>
      enrollment report
    </a>
  {% else %}
    {% gloss "IPEDS" %}
    <a href="http://nces.ed.gov/ipeds/datacenter/">Data Center</a>
    and the
    {% gloss "THECB" %}
    <a href="http://www.txhighereddata.org/approot/dwprodrpt/enrmenu.htm">
      <abbr title="Profile Reports Electronically Produced">PREP</abbr>
      enrollment report
    </a>
    and
    <a href="http://www.txhighereddata.org/interactive/accountability">
      Accountability System
    </a>
  {% endif %}
</p>
