{% extends "tx_highered/app_base.html" %}
{% load static from staticfiles %}


{% block opengraph_meta %}{{ block.super }}
  <meta property="og:title" content="The Texas Tribune Higher Education Explorer">
  <meta property="og:description" content="The Texas Tribune Higher Education Explorer captures data on all 148 public and private colleges and universities in the state. Combining key academic, enrollment and financial records, this database collects and presents statistics about Texas’ institutions of higher learning in a way that is easy to understand and simple to navigate.">
{% endblock %}


{% block adsense_slots %}{{ block.super }}
  {% include "tx_highered/includes/app_meta.html" %}
{% endblock %}


{% block main_base %}
  <div class="row landing">
    <div class="span8">
      {% block main %}{% endblock %}
    </div>

    <div class="span4">
      <div class="well presented_by">
        <p>
          The <a href="{% url 'tx_highered:home' %}">Higher Education Explorer</a> was created with<br>
          support from the Greater Texas Foundation.
        </p>

        <div class="logo">
          <a class="external" target="_blank" href="http://greatertexasfoundation.org/">
            <img src="{% static 'tx_highered/images/greater-texas-foundation.png' %}" alt="Greater Texas Foundation">
          </a>
        </div>

        <p>
          <a href="{% url 'tx_highered:home' %}about/">
            Learn more about the<br> Higher Education Explorer
          </a>
        </p>
      </div>

      {% include "tx_highered/includes/home_rail.html" %}
    </div>
  </div>
{% endblock %}
