{% load layout_helpers %}
<table class="data-source chart-data table table-striped table-condensed">
  <thead>
    <tr>
      <th rowspan=2>Year</th>
      <th colspan=3>Scores <small>(25th percentile - 75th percentile)</small></th>
    </tr>
    <tr>
      <th>Critical Reading</th>
      <th>Math</th>
      <th>Writing</th>
    </tr>
  </thead>
  {# {% render_list object_list "testscores_tbody" %} #}
  {% render_list object_list "testscores_tbody_basic" %}
</table>
