{% extends "tx_highered/app_base.html" %}
{% load layout_helpers %}


{% block head_title %}Test Scores{% endblock %}


{% block extra_style %}{{ block.super }}
<style type="text/css">
.paper {
  min-width: 600px;
}
</style>
{% endblock %}


{% block main %}
<table class="table table-striped table-bordered">
  <thead>
    <tr>
      <th>School</th>
      <th>Scores</th>
    </tr>
  </thead>
  {% for object in object_list %}
    {% if object.scores %}
      {% with tbody_label=object.name %}
        {% render_model object.scores "testscores_tbody" %}
      {% endwith %}
    {% endif %}
  {% endfor %}
</table>
{% endblock %}
