<table class="chart-data data-source table table-striped table-condensed">
  <thead>
    <tr>
      <td></td>
      <td colspan=3>Graduation Rates (Bachelor's Degree)</td>
    </tr>
    <tr>
      <th>Year</th>
      <th>4-Year</th>
      <th>5-Year</th>
      <th>6-Year</th>
    </tr>
  </thead>
  <tbody>
    {% for object in object_list %}
      <tr>
        <th data-value="{{ object.year }}">{{ object.display_year }}</th>
        <td data-value="{{ object.bachelor_4yr|default:"0" }}">
          {{ object.bachelor_4yr }}%
        </td>
        <td data-value="{{ object.bachelor_5yr|default:"0" }}">
          {{ object.bachelor_5yr }}%
        </td>
        <td data-value="{{ object.bachelor_6yr|default:"0" }}">
          {{ object.bachelor_6yr }}%
        </td>
      </tr>
    {% endfor %}
  </tbody>
</table>
