{% extends "tx_highered/app_base.html" %}


{% block head_title %}Institutions{% endblock %}


{% block breadcrumb_items %}
  <li class="active"><a href="">Institutions</a></li>
{% endblock %}


{% block main %}
  <header class="page-header">
    <h1>Directory</h1>
  </header>

  {% for object in object_list %}
    <div id="{{ object.slug }}" class="row">
      <div class="span12">
        <h2>
          <a href="{{ object.get_absolute_url }}">{{ object.name }}</a>

          <small>{{ object.type }}</small>
        </h2>

        {% include "tx_highered/includes/sentences.html" %}
      </div>
    </div>
  {% endfor %}
{% endblock %}
