{# %7C is the pipe (|) separator #}
<img src="//maps.googleapis.com/maps/api/staticmap?zoom=13&amp;size=231x231&amp;markers=color:blue%7C{{ object.location.y }},{{ object.location.x }}&amp;sensor=false">
