{% comment %}
FIXME magic string: texastribune.map-3g2hqvcf
{% endcomment %}
<img src="//api.tiles.mapbox.com/v3/texastribune.map-3g2hqvcf/pin-m-star+48a({{ object.location.x }},{{ object.location.y}})/{{ object.location.x }},{{ object.location.y}},12/{{ w|default:"300" }}x{{ h|default:"300" }}.png">
