{% load layout_helpers %}
<table class="layout-table">
  <tr>
    <th>Name</th>
    <td>{{ object.name }}</td>
  </tr>
  <tr>
    <th>slug</th>
    <td>{{ object.slug }}</td>
  </tr>
  <tr>
    <th>IPEDS ID</th>
    <td>{{ object.ipeds_id }}</td>
  </tr>
  <tr>
    <th>OPE ID</th>
    <td>{{ object.ope_id }}</td>
  </tr>
  {% if object.system %}
	  <tr>
	    <th>System</th>
	    <td>{{ object.system }}</td>
	  </tr>
  {% endif %}
  {% render_model object "contactfields_as_rows" %}
</table>
