{% extends "tx_highered/app_base.html" %}


{% block head_title %}Systems{% endblock %}


{% block main %}
<ul>
  {% for object in object_list %}
    <li>
      <a href="{{ object.get_absolute_url }}">{{ object }}</a>
      {% if object.institution.exists %}
        <ul>
          {% for inst in object.institution.all %}
            <li><a href="{{ inst.get_absolute_url }}">{{ inst.name }}</a></li>
          {% endfor %}
        </ul>
      {% endif %}
    </li>
  {% endfor %}
</ul>
{% endblock %}
