{% extends "tx_highered/app_base.html" %}
{% load layout_helpers humanize instachart %}


{% block head_title %}The Funnel{% endblock %}
{% block page_title %}The Funnel{% endblock %}


{% block main %}
  {% for object in object_list %}{% if object.funnels %}
    <h3><a href="{{ object.get_absolute_url }}">{{ object.name }}</a></h3>
    {% render_model object "funnels" %}
  {% endif %}{% endfor %}
{% endblock %}


{% block rail %}
  {% render_model object "table" %}
{% endblock %}


{% block extra_script %}{{ block.super }}
<script>
  $(".onion").onionize({
    animate: false,
    afterFold: function(e, ui){
      console.log(e, ui);
      ui.elem.siblings(".onion").not(".ui-onion-active").onionize("fold");
    },
    afterUnfold: function(e, ui){
      console.log(e, ui);
      ui.elem.siblings(".onion.ui-onion-active").onionize("unfold");
    }
  });
</script>
{% endblock %}
