/*
 * Bootstrap v2.0.4
 *
 * Copyright 2012 Twitter, Inc
 * Licensed under the Apache License v2.0
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Designed and built with all the love in the world @twitter by @mdo and @fat.
 */
.clearfix {
  *zoom: 1; }
  .clearfix:before, .clearfix:after {
    display: table;
    content: ""; }
  .clearfix:after {
    clear: both; }

.hide-text {
  font: 0/0 a;
  color: transparent;
  text-shadow: none;
  background-color: transparent;
  border: 0; }

.input-block-level {
  display: block;
  width: 100%;
  min-height: 28px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box; }

.bootstrap {
  margin: 0;
  font-family: Georgia, "Times New Roman", Times, serif;
  font-size: 15px;
  line-height: 20px;
  color: #333333;
  background-color: white;
  @-webkit-keyframes progress-bar-stripes {
    from {
      background-position: 40px 0; }

    to {
      background-position: 0 0; } }

  @-moz-keyframes progress-bar-stripes {
    from {
      background-position: 40px 0; }

    to {
      background-position: 0 0; } }

  @-ms-keyframes progress-bar-stripes {
    from {
      background-position: 40px 0; }

    to {
      background-position: 0 0; } }

  @-o-keyframes progress-bar-stripes {
    from {
      background-position: 0 0; }

    to {
      background-position: 40px 0; } }

  @keyframes progress-bar-stripes {
    from {
      background-position: 40px 0; }

    to {
      background-position: 0 0; } }
 }
  .bootstrap article,
  .bootstrap aside,
  .bootstrap details,
  .bootstrap figcaption,
  .bootstrap figure,
  .bootstrap footer,
  .bootstrap header,
  .bootstrap hgroup,
  .bootstrap nav,
  .bootstrap section {
    display: block; }
  .bootstrap audio,
  .bootstrap canvas,
  .bootstrap video {
    display: inline-block;
    *display: inline;
    *zoom: 1; }
  .bootstrap audio:not([controls]) {
    display: none; }
  .bootstrap html {
    font-size: 100%;
    -webkit-text-size-adjust: 100%;
    -ms-text-size-adjust: 100%; }
  .bootstrap a:focus {
    outline: thin dotted #333;
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px; }
  .bootstrap a:hover,
  .bootstrap a:active {
    outline: 0; }
  .bootstrap sub,
  .bootstrap sup {
    position: relative;
    font-size: 75%;
    line-height: 0;
    vertical-align: baseline; }
  .bootstrap sup {
    top: -0.5em; }
  .bootstrap sub {
    bottom: -0.25em; }
  .bootstrap img {
    max-width: 100%;
    vertical-align: middle;
    border: 0;
    -ms-interpolation-mode: bicubic; }
  .bootstrap #map_canvas img {
    max-width: none; }
  .bootstrap button,
  .bootstrap input,
  .bootstrap select,
  .bootstrap textarea {
    margin: 0;
    font-size: 100%;
    vertical-align: middle; }
  .bootstrap button,
  .bootstrap input {
    *overflow: visible;
    line-height: normal; }
  .bootstrap button::-moz-focus-inner,
  .bootstrap input::-moz-focus-inner {
    padding: 0;
    border: 0; }
  .bootstrap button,
  .bootstrap input[type="button"],
  .bootstrap input[type="reset"],
  .bootstrap input[type="submit"] {
    cursor: pointer;
    -webkit-appearance: button; }
  .bootstrap input[type="search"] {
    -webkit-box-sizing: content-box;
    -moz-box-sizing: content-box;
    box-sizing: content-box;
    -webkit-appearance: textfield; }
  .bootstrap input[type="search"]::-webkit-search-decoration,
  .bootstrap input[type="search"]::-webkit-search-cancel-button {
    -webkit-appearance: none; }
  .bootstrap textarea {
    overflow: auto;
    vertical-align: top; }
  .bootstrap p {
    font-size: 100%; }
  .bootstrap body {
    margin: 0;
    font-family: Georgia, "Times New Roman", Times, serif;
    font-size: 15px;
    line-height: 20px;
    color: #333333;
    background-color: white; }
  .bootstrap a {
    color: #008990;
    text-decoration: none; }
  .bootstrap a:hover {
    color: #004044;
    text-decoration: underline; }
  .bootstrap .row {
    margin-left: -12px;
    *zoom: 1; }
    .bootstrap .row:before, .bootstrap .row:after {
      display: table;
      content: ""; }
    .bootstrap .row:after {
      clear: both; }
  .bootstrap [class*="span"] {
    float: left;
    margin-left: 12px; }
  .bootstrap .container,
  .bootstrap .navbar-fixed-top .container,
  .bootstrap .navbar-fixed-bottom .container {
    width: 960px; }
  .bootstrap .span12 {
    width: 960px; }
  .bootstrap .span11 {
    width: 879px; }
  .bootstrap .span10 {
    width: 798px; }
  .bootstrap .span9 {
    width: 717px; }
  .bootstrap .span8 {
    width: 636px; }
  .bootstrap .span7 {
    width: 555px; }
  .bootstrap .span6 {
    width: 474px; }
  .bootstrap .span5 {
    width: 393px; }
  .bootstrap .span4 {
    width: 312px; }
  .bootstrap .span3 {
    width: 231px; }
  .bootstrap .span2 {
    width: 150px; }
  .bootstrap .span1 {
    width: 69px; }
  .bootstrap .offset12 {
    margin-left: 984px; }
  .bootstrap .offset11 {
    margin-left: 903px; }
  .bootstrap .offset10 {
    margin-left: 822px; }
  .bootstrap .offset9 {
    margin-left: 741px; }
  .bootstrap .offset8 {
    margin-left: 660px; }
  .bootstrap .offset7 {
    margin-left: 579px; }
  .bootstrap .offset6 {
    margin-left: 498px; }
  .bootstrap .offset5 {
    margin-left: 417px; }
  .bootstrap .offset4 {
    margin-left: 336px; }
  .bootstrap .offset3 {
    margin-left: 255px; }
  .bootstrap .offset2 {
    margin-left: 174px; }
  .bootstrap .offset1 {
    margin-left: 93px; }
  .bootstrap .row-fluid {
    width: 100%;
    *zoom: 1; }
    .bootstrap .row-fluid:before, .bootstrap .row-fluid:after {
      display: table;
      content: ""; }
    .bootstrap .row-fluid:after {
      clear: both; }
    .bootstrap .row-fluid [class*="span"] {
      display: block;
      width: 100%;
      min-height: 28px;
      -webkit-box-sizing: border-box;
      -moz-box-sizing: border-box;
      -ms-box-sizing: border-box;
      box-sizing: border-box;
      float: left;
      margin-left: 2.12766%;
      *margin-left: 2.07558%; }
    .bootstrap .row-fluid [class*="span"]:first-child {
      margin-left: 0; }
    .bootstrap .row-fluid .span12 {
      width: 100.0%;
      *width: 99.94792%; }
    .bootstrap .row-fluid .span11 {
      width: 91.48936%;
      *width: 91.43728%; }
    .bootstrap .row-fluid .span10 {
      width: 82.97872%;
      *width: 82.92664%; }
    .bootstrap .row-fluid .span9 {
      width: 74.46809%;
      *width: 74.416%; }
    .bootstrap .row-fluid .span8 {
      width: 65.95745%;
      *width: 65.90536%; }
    .bootstrap .row-fluid .span7 {
      width: 57.44681%;
      *width: 57.39473%; }
    .bootstrap .row-fluid .span6 {
      width: 48.93617%;
      *width: 48.88409%; }
    .bootstrap .row-fluid .span5 {
      width: 40.42553%;
      *width: 40.37345%; }
    .bootstrap .row-fluid .span4 {
      width: 31.91489%;
      *width: 31.86281%; }
    .bootstrap .row-fluid .span3 {
      width: 23.40426%;
      *width: 23.35217%; }
    .bootstrap .row-fluid .span2 {
      width: 14.89362%;
      *width: 14.84153%; }
    .bootstrap .row-fluid .span1 {
      width: 6.38298%;
      *width: 6.3309%; }
  .bootstrap .container {
    margin-right: auto;
    margin-left: auto;
    *zoom: 1; }
    .bootstrap .container:before, .bootstrap .container:after {
      display: table;
      content: ""; }
    .bootstrap .container:after {
      clear: both; }
  .bootstrap .container-fluid {
    padding-right: 12px;
    padding-left: 12px;
    *zoom: 1; }
    .bootstrap .container-fluid:before, .bootstrap .container-fluid:after {
      display: table;
      content: ""; }
    .bootstrap .container-fluid:after {
      clear: both; }
  .bootstrap p {
    margin: 0 0 10px; }
    .bootstrap p small {
      font-size: 13px;
      color: #999999; }
  .bootstrap .lead {
    margin-bottom: 20px;
    font-size: 20px;
    font-weight: 200;
    line-height: 30px; }
  .bootstrap h1, .bootstrap h2, .bootstrap h3, .bootstrap h4, .bootstrap h5, .bootstrap h6 {
    margin: 0;
    font-family: inherit;
    font-weight: bold;
    color: inherit;
    text-rendering: optimizelegibility; }
    .bootstrap h1 small, .bootstrap h2 small, .bootstrap h3 small, .bootstrap h4 small, .bootstrap h5 small, .bootstrap h6 small {
      font-weight: normal;
      color: #999999; }
  .bootstrap h1 {
    font-size: 30px;
    line-height: 40px; }
    .bootstrap h1 small {
      font-size: 18px; }
  .bootstrap h2 {
    font-size: 24px;
    line-height: 40px; }
    .bootstrap h2 small {
      font-size: 18px; }
  .bootstrap h3 {
    font-size: 18px;
    line-height: 30px; }
    .bootstrap h3 small {
      font-size: 14px; }
  .bootstrap h4, .bootstrap h5, .bootstrap h6 {
    line-height: 20px; }
  .bootstrap h4 {
    font-size: 14px; }
    .bootstrap h4 small {
      font-size: 12px; }
  .bootstrap h5 {
    font-size: 12px; }
  .bootstrap h6 {
    font-size: 11px;
    color: #999999;
    text-transform: uppercase; }
  .bootstrap .page-header {
    padding-bottom: 9px;
    margin: 10px 0;
    border-bottom: 1px solid #999999; }
  .bootstrap .page-header h1 {
    line-height: 1; }
  .bootstrap ul, .bootstrap ol {
    padding: 0;
    margin: 0 0 10px 25px; }
  .bootstrap ul ul,
  .bootstrap ul ol,
  .bootstrap ol ol,
  .bootstrap ol ul {
    margin-bottom: 0; }
  .bootstrap ul {
    list-style: disc; }
  .bootstrap ol {
    list-style: decimal; }
  .bootstrap li {
    line-height: 20px; }
  .bootstrap ul.unstyled,
  .bootstrap ol.unstyled {
    margin-left: 0;
    list-style: none; }
  .bootstrap dl {
    margin-bottom: 20px; }
  .bootstrap dt,
  .bootstrap dd {
    line-height: 20px; }
  .bootstrap dt {
    font-weight: bold;
    line-height: 19px; }
  .bootstrap dd {
    margin-left: 10px; }
  .bootstrap .dl-horizontal dt {
    float: left;
    width: 120px;
    clear: left;
    text-align: right;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap; }
  .bootstrap .dl-horizontal dd {
    margin-left: 130px; }
  .bootstrap hr {
    margin: 20px 0;
    border: 0;
    border-top: 1px solid #eeeeee;
    border-bottom: 1px solid white; }
  .bootstrap strong {
    font-weight: bold; }
  .bootstrap em {
    font-style: italic; }
  .bootstrap .muted {
    color: #999999; }
  .bootstrap abbr[title] {
    cursor: help;
    border-bottom: 1px dotted #999999; }
  .bootstrap abbr.initialism {
    font-size: 90%;
    text-transform: uppercase; }
  .bootstrap blockquote {
    padding: 0 0 0 15px;
    margin: 0 0 20px;
    border-left: 5px solid #eeeeee; }
    .bootstrap blockquote p {
      margin-bottom: 0;
      font-size: 16px;
      font-weight: 300;
      line-height: 25px; }
    .bootstrap blockquote small {
      display: block;
      line-height: 20px;
      color: #999999; }
      .bootstrap blockquote small:before {
        content: '\2014 \00A0'; }
    .bootstrap blockquote.pull-right {
      float: right;
      padding-right: 15px;
      padding-left: 0;
      border-right: 5px solid #eeeeee;
      border-left: 0; }
      .bootstrap blockquote.pull-right p,
      .bootstrap blockquote.pull-right small {
        text-align: right; }
  .bootstrap q:before,
  .bootstrap q:after,
  .bootstrap blockquote:before,
  .bootstrap blockquote:after {
    content: ""; }
  .bootstrap address {
    display: block;
    margin-bottom: 20px;
    font-style: normal;
    line-height: 20px; }
  .bootstrap small {
    font-size: 100%; }
  .bootstrap cite {
    font-style: normal; }
  .bootstrap code,
  .bootstrap pre {
    padding: 0 3px 2px;
    font-family: Menlo, Monaco, Consolas, "Courier New", monospace;
    font-size: 14px;
    color: #333333;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px; }
  .bootstrap code {
    padding: 2px 4px;
    color: #d14;
    background-color: #f7f7f9;
    border: 1px solid #e1e1e8; }
  .bootstrap pre {
    display: block;
    padding: 9.5px;
    margin: 0 0 10px;
    font-size: 13.875px;
    line-height: 20px;
    word-break: break-all;
    word-wrap: break-word;
    white-space: pre;
    white-space: pre-wrap;
    background-color: #f5f5f5;
    border: 1px solid #ccc;
    border: 1px solid rgba(0, 0, 0, 0.15);
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px; }
    .bootstrap pre.prettyprint {
      margin-bottom: 20px; }
    .bootstrap pre code {
      padding: 0;
      color: inherit;
      background-color: transparent;
      border: 0; }
  .bootstrap .pre-scrollable {
    max-height: 340px;
    overflow-y: scroll; }
  .bootstrap form {
    margin: 0 0 20px; }
  .bootstrap fieldset {
    padding: 0;
    margin: 0;
    border: 0; }
  .bootstrap legend {
    display: block;
    width: 100%;
    padding: 0;
    margin-bottom: 30px;
    font-size: 22.5px;
    line-height: 40px;
    color: #333333;
    border: 0;
    border-bottom: 1px solid #e5e5e5; }
    .bootstrap legend small {
      font-size: 15px;
      color: #999999; }
  .bootstrap label,
  .bootstrap input,
  .bootstrap button,
  .bootstrap select,
  .bootstrap textarea {
    font-size: 15px;
    font-weight: normal;
    line-height: 20px; }
  .bootstrap input,
  .bootstrap button,
  .bootstrap select,
  .bootstrap textarea {
    font-family: "Helvetica Neue", Helvetica, Arial, sans-serif; }
  .bootstrap label {
    display: block;
    margin-bottom: 5px; }
  .bootstrap select,
  .bootstrap textarea,
  .bootstrap input[type="text"],
  .bootstrap input[type="password"],
  .bootstrap input[type="datetime"],
  .bootstrap input[type="datetime-local"],
  .bootstrap input[type="date"],
  .bootstrap input[type="month"],
  .bootstrap input[type="time"],
  .bootstrap input[type="week"],
  .bootstrap input[type="number"],
  .bootstrap input[type="email"],
  .bootstrap input[type="url"],
  .bootstrap input[type="search"],
  .bootstrap input[type="tel"],
  .bootstrap input[type="color"],
  .bootstrap .uneditable-input {
    display: inline-block;
    height: 20px;
    padding: 4px;
    margin-bottom: 9px;
    font-size: 15px;
    line-height: 20px;
    color: #555555; }
  .bootstrap input,
  .bootstrap textarea {
    width: 210px; }
  .bootstrap textarea {
    height: auto; }
  .bootstrap textarea,
  .bootstrap input[type="text"],
  .bootstrap input[type="password"],
  .bootstrap input[type="datetime"],
  .bootstrap input[type="datetime-local"],
  .bootstrap input[type="date"],
  .bootstrap input[type="month"],
  .bootstrap input[type="time"],
  .bootstrap input[type="week"],
  .bootstrap input[type="number"],
  .bootstrap input[type="email"],
  .bootstrap input[type="url"],
  .bootstrap input[type="search"],
  .bootstrap input[type="tel"],
  .bootstrap input[type="color"],
  .bootstrap .uneditable-input {
    background-color: white;
    border: 1px solid #cccccc;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    -webkit-transition: border linear 0.2s, box-shadow linear 0.2s;
    -moz-transition: border linear 0.2s, box-shadow linear 0.2s;
    -ms-transition: border linear 0.2s, box-shadow linear 0.2s;
    -o-transition: border linear 0.2s, box-shadow linear 0.2s;
    transition: border linear 0.2s, box-shadow linear 0.2s; }
    .bootstrap textarea:focus,
    .bootstrap input[type="text"]:focus,
    .bootstrap input[type="password"]:focus,
    .bootstrap input[type="datetime"]:focus,
    .bootstrap input[type="datetime-local"]:focus,
    .bootstrap input[type="date"]:focus,
    .bootstrap input[type="month"]:focus,
    .bootstrap input[type="time"]:focus,
    .bootstrap input[type="week"]:focus,
    .bootstrap input[type="number"]:focus,
    .bootstrap input[type="email"]:focus,
    .bootstrap input[type="url"]:focus,
    .bootstrap input[type="search"]:focus,
    .bootstrap input[type="tel"]:focus,
    .bootstrap input[type="color"]:focus,
    .bootstrap .uneditable-input:focus {
      border-color: rgba(82, 168, 236, 0.8);
      outline: 0;
      outline: thin dotted \9;
      /* IE6-9 */
      -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(82, 168, 236, 0.6);
      -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(82, 168, 236, 0.6);
      box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(82, 168, 236, 0.6); }
  .bootstrap input[type="radio"],
  .bootstrap input[type="checkbox"] {
    margin: 3px 0;
    *margin-top: 0;
    /* IE7 */
    line-height: normal;
    cursor: pointer; }
  .bootstrap input[type="submit"],
  .bootstrap input[type="reset"],
  .bootstrap input[type="button"],
  .bootstrap input[type="radio"],
  .bootstrap input[type="checkbox"] {
    width: auto; }
  .bootstrap .uneditable-textarea {
    width: auto;
    height: auto; }
  .bootstrap select,
  .bootstrap input[type="file"] {
    height: 28px;
    /* In IE7, the height of the select element cannot be changed by height, only font-size */
    *margin-top: 4px;
    /* For IE7, add top margin to align select with labels */
    line-height: 28px; }
  .bootstrap select {
    width: 220px;
    border: 1px solid #bbb; }
  .bootstrap select[multiple],
  .bootstrap select[size] {
    height: auto; }
  .bootstrap select:focus,
  .bootstrap input[type="file"]:focus,
  .bootstrap input[type="radio"]:focus,
  .bootstrap input[type="checkbox"]:focus {
    outline: thin dotted #333;
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px; }
  .bootstrap .radio,
  .bootstrap .checkbox {
    min-height: 18px;
    padding-left: 18px; }
  .bootstrap .radio input[type="radio"],
  .bootstrap .checkbox input[type="checkbox"] {
    float: left;
    margin-left: -18px; }
  .bootstrap .controls > .radio:first-child,
  .bootstrap .controls > .checkbox:first-child {
    padding-top: 5px; }
  .bootstrap .radio.inline,
  .bootstrap .checkbox.inline {
    display: inline-block;
    padding-top: 5px;
    margin-bottom: 0;
    vertical-align: middle; }
  .bootstrap .radio.inline + .radio.inline,
  .bootstrap .checkbox.inline + .checkbox.inline {
    margin-left: 10px; }
  .bootstrap .input-mini {
    width: 60px; }
  .bootstrap .input-small {
    width: 90px; }
  .bootstrap .input-medium {
    width: 150px; }
  .bootstrap .input-large {
    width: 210px; }
  .bootstrap .input-xlarge {
    width: 270px; }
  .bootstrap .input-xxlarge {
    width: 530px; }
  .bootstrap input[class*="span"],
  .bootstrap select[class*="span"],
  .bootstrap textarea[class*="span"],
  .bootstrap .uneditable-input[class*="span"],
  .bootstrap .row-fluid input[class*="span"],
  .bootstrap .row-fluid select[class*="span"],
  .bootstrap .row-fluid textarea[class*="span"],
  .bootstrap .row-fluid .uneditable-input[class*="span"] {
    float: none;
    margin-left: 0; }
  .bootstrap .input-append input[class*="span"],
  .bootstrap .input-append .uneditable-input[class*="span"],
  .bootstrap .input-prepend input[class*="span"],
  .bootstrap .input-prepend .uneditable-input[class*="span"],
  .bootstrap .row-fluid .input-prepend [class*="span"],
  .bootstrap .row-fluid .input-append [class*="span"] {
    display: inline-block; }
  .bootstrap input,
  .bootstrap textarea,
  .bootstrap .uneditable-input {
    margin-left: 0; }
  .bootstrap input[disabled],
  .bootstrap select[disabled],
  .bootstrap textarea[disabled],
  .bootstrap input[readonly],
  .bootstrap select[readonly],
  .bootstrap textarea[readonly] {
    cursor: not-allowed;
    background-color: #eeeeee;
    border-color: #ddd; }
  .bootstrap input[type="radio"][disabled],
  .bootstrap input[type="checkbox"][disabled],
  .bootstrap input[type="radio"][readonly],
  .bootstrap input[type="checkbox"][readonly] {
    background-color: transparent; }
  .bootstrap .control-group.warning > label,
  .bootstrap .control-group.warning .help-block,
  .bootstrap .control-group.warning .help-inline {
    color: #c09853; }
  .bootstrap .control-group.warning .checkbox,
  .bootstrap .control-group.warning .radio,
  .bootstrap .control-group.warning input,
  .bootstrap .control-group.warning select,
  .bootstrap .control-group.warning textarea {
    color: #c09853;
    border-color: #c09853; }
    .bootstrap .control-group.warning .checkbox:focus,
    .bootstrap .control-group.warning .radio:focus,
    .bootstrap .control-group.warning input:focus,
    .bootstrap .control-group.warning select:focus,
    .bootstrap .control-group.warning textarea:focus {
      border-color: #a47e3c;
      -webkit-box-shadow: 0 0 6px #dbc59e;
      -moz-box-shadow: 0 0 6px #dbc59e;
      box-shadow: 0 0 6px #dbc59e; }
  .bootstrap .control-group.warning .input-prepend .add-on,
  .bootstrap .control-group.warning .input-append .add-on {
    color: #c09853;
    background-color: #fcf8e3;
    border-color: #c09853; }
  .bootstrap .control-group.error > label,
  .bootstrap .control-group.error .help-block,
  .bootstrap .control-group.error .help-inline {
    color: #b94a48; }
  .bootstrap .control-group.error .checkbox,
  .bootstrap .control-group.error .radio,
  .bootstrap .control-group.error input,
  .bootstrap .control-group.error select,
  .bootstrap .control-group.error textarea {
    color: #b94a48;
    border-color: #b94a48; }
    .bootstrap .control-group.error .checkbox:focus,
    .bootstrap .control-group.error .radio:focus,
    .bootstrap .control-group.error input:focus,
    .bootstrap .control-group.error select:focus,
    .bootstrap .control-group.error textarea:focus {
      border-color: #953b39;
      -webkit-box-shadow: 0 0 6px #d59392;
      -moz-box-shadow: 0 0 6px #d59392;
      box-shadow: 0 0 6px #d59392; }
  .bootstrap .control-group.error .input-prepend .add-on,
  .bootstrap .control-group.error .input-append .add-on {
    color: #b94a48;
    background-color: #f2dede;
    border-color: #b94a48; }
  .bootstrap .control-group.success > label,
  .bootstrap .control-group.success .help-block,
  .bootstrap .control-group.success .help-inline {
    color: #468847; }
  .bootstrap .control-group.success .checkbox,
  .bootstrap .control-group.success .radio,
  .bootstrap .control-group.success input,
  .bootstrap .control-group.success select,
  .bootstrap .control-group.success textarea {
    color: #468847;
    border-color: #468847; }
    .bootstrap .control-group.success .checkbox:focus,
    .bootstrap .control-group.success .radio:focus,
    .bootstrap .control-group.success input:focus,
    .bootstrap .control-group.success select:focus,
    .bootstrap .control-group.success textarea:focus {
      border-color: #356635;
      -webkit-box-shadow: 0 0 6px #7aba7b;
      -moz-box-shadow: 0 0 6px #7aba7b;
      box-shadow: 0 0 6px #7aba7b; }
  .bootstrap .control-group.success .input-prepend .add-on,
  .bootstrap .control-group.success .input-append .add-on {
    color: #468847;
    background-color: #dff0d8;
    border-color: #468847; }
  .bootstrap input:focus:required:invalid,
  .bootstrap textarea:focus:required:invalid,
  .bootstrap select:focus:required:invalid {
    color: #b94a48;
    border-color: #ee5f5b; }
    .bootstrap input:focus:required:invalid:focus,
    .bootstrap textarea:focus:required:invalid:focus,
    .bootstrap select:focus:required:invalid:focus {
      border-color: #e9322d;
      -webkit-box-shadow: 0 0 6px #f8b9b7;
      -moz-box-shadow: 0 0 6px #f8b9b7;
      box-shadow: 0 0 6px #f8b9b7; }
  .bootstrap .form-actions {
    padding: 19px 20px 20px;
    margin-top: 20px;
    margin-bottom: 20px;
    background-color: whitesmoke;
    border-top: 1px solid #e5e5e5;
    *zoom: 1; }
    .bootstrap .form-actions:before, .bootstrap .form-actions:after {
      display: table;
      content: ""; }
    .bootstrap .form-actions:after {
      clear: both; }
  .bootstrap .uneditable-input {
    overflow: hidden;
    white-space: nowrap;
    cursor: not-allowed;
    background-color: white;
    border-color: #eee;
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.025);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.025);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.025); }
  .bootstrap :-moz-placeholder {
    color: #999999; }
  .bootstrap :-ms-input-placeholder {
    color: #999999; }
  .bootstrap ::-webkit-input-placeholder {
    color: #999999; }
  .bootstrap .help-block,
  .bootstrap .help-inline {
    color: #555555; }
  .bootstrap .help-block {
    display: block;
    margin-bottom: 10px; }
  .bootstrap .help-inline {
    display: inline-block;
    *display: inline;
    *zoom: 1;
    vertical-align: middle;
    padding-left: 5px; }
  .bootstrap .input-prepend,
  .bootstrap .input-append {
    margin-bottom: 5px; }
    .bootstrap .input-prepend input,
    .bootstrap .input-prepend select,
    .bootstrap .input-prepend .uneditable-input,
    .bootstrap .input-append input,
    .bootstrap .input-append select,
    .bootstrap .input-append .uneditable-input {
      position: relative;
      margin-bottom: 0;
      *margin-left: 0;
      vertical-align: middle;
      -webkit-border-radius: 0 3px 3px 0;
      -moz-border-radius: 0 3px 3px 0;
      border-radius: 0 3px 3px 0; }
      .bootstrap .input-prepend input:focus,
      .bootstrap .input-prepend select:focus,
      .bootstrap .input-prepend .uneditable-input:focus,
      .bootstrap .input-append input:focus,
      .bootstrap .input-append select:focus,
      .bootstrap .input-append .uneditable-input:focus {
        z-index: 2; }
    .bootstrap .input-prepend .uneditable-input,
    .bootstrap .input-append .uneditable-input {
      border-left-color: #ccc; }
    .bootstrap .input-prepend .add-on,
    .bootstrap .input-append .add-on {
      display: inline-block;
      width: auto;
      height: 20px;
      min-width: 16px;
      padding: 4px 5px;
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
      font-weight: normal;
      line-height: 20px;
      text-align: center;
      text-shadow: 0 1px 0 white;
      vertical-align: middle;
      background-color: #eeeeee;
      border: 1px solid #ccc; }
    .bootstrap .input-prepend .add-on,
    .bootstrap .input-prepend .btn,
    .bootstrap .input-append .add-on,
    .bootstrap .input-append .btn {
      margin-left: -1px;
      -webkit-border-radius: 0;
      -moz-border-radius: 0;
      border-radius: 0; }
    .bootstrap .input-prepend .active,
    .bootstrap .input-append .active {
      background-color: #a9dba9;
      border-color: #46a546; }
  .bootstrap .input-prepend .add-on,
  .bootstrap .input-prepend .btn {
    margin-right: -1px; }
  .bootstrap .input-prepend .add-on:first-child,
  .bootstrap .input-prepend .btn:first-child {
    -webkit-border-radius: 3px 0 0 3px;
    -moz-border-radius: 3px 0 0 3px;
    border-radius: 3px 0 0 3px; }
  .bootstrap .input-append input,
  .bootstrap .input-append select,
  .bootstrap .input-append .uneditable-input {
    -webkit-border-radius: 3px 0 0 3px;
    -moz-border-radius: 3px 0 0 3px;
    border-radius: 3px 0 0 3px; }
  .bootstrap .input-append .uneditable-input {
    border-right-color: #ccc;
    border-left-color: #eee; }
  .bootstrap .input-append .add-on:last-child,
  .bootstrap .input-append .btn:last-child {
    -webkit-border-radius: 0 3px 3px 0;
    -moz-border-radius: 0 3px 3px 0;
    border-radius: 0 3px 3px 0; }
  .bootstrap .input-prepend.input-append input,
  .bootstrap .input-prepend.input-append select,
  .bootstrap .input-prepend.input-append .uneditable-input {
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    border-radius: 0; }
  .bootstrap .input-prepend.input-append .add-on:first-child,
  .bootstrap .input-prepend.input-append .btn:first-child {
    margin-right: -1px;
    -webkit-border-radius: 3px 0 0 3px;
    -moz-border-radius: 3px 0 0 3px;
    border-radius: 3px 0 0 3px; }
  .bootstrap .input-prepend.input-append .add-on:last-child,
  .bootstrap .input-prepend.input-append .btn:last-child {
    margin-left: -1px;
    -webkit-border-radius: 0 3px 3px 0;
    -moz-border-radius: 0 3px 3px 0;
    border-radius: 0 3px 3px 0; }
  .bootstrap .search-query {
    padding-right: 14px;
    padding-right: 4px \9;
    padding-left: 14px;
    padding-left: 4px \9;
    /* IE7-8 doesn't have border-radius, so don't indent the padding */
    margin-bottom: 0;
    -webkit-border-radius: 14px;
    -moz-border-radius: 14px;
    border-radius: 14px; }
  .bootstrap .form-search input,
  .bootstrap .form-search textarea,
  .bootstrap .form-search select,
  .bootstrap .form-search .help-inline,
  .bootstrap .form-search .uneditable-input,
  .bootstrap .form-search .input-prepend,
  .bootstrap .form-search .input-append,
  .bootstrap .form-inline input,
  .bootstrap .form-inline textarea,
  .bootstrap .form-inline select,
  .bootstrap .form-inline .help-inline,
  .bootstrap .form-inline .uneditable-input,
  .bootstrap .form-inline .input-prepend,
  .bootstrap .form-inline .input-append,
  .bootstrap .form-horizontal input,
  .bootstrap .form-horizontal textarea,
  .bootstrap .form-horizontal select,
  .bootstrap .form-horizontal .help-inline,
  .bootstrap .form-horizontal .uneditable-input,
  .bootstrap .form-horizontal .input-prepend,
  .bootstrap .form-horizontal .input-append {
    display: inline-block;
    *display: inline;
    *zoom: 1;
    margin-bottom: 0; }
  .bootstrap .form-search .hide,
  .bootstrap .form-inline .hide,
  .bootstrap .form-horizontal .hide {
    display: none; }
  .bootstrap .form-search label,
  .bootstrap .form-inline label {
    display: inline-block; }
  .bootstrap .form-search .input-append,
  .bootstrap .form-inline .input-append,
  .bootstrap .form-search .input-prepend,
  .bootstrap .form-inline .input-prepend {
    margin-bottom: 0; }
  .bootstrap .form-search .radio,
  .bootstrap .form-search .checkbox,
  .bootstrap .form-inline .radio,
  .bootstrap .form-inline .checkbox {
    padding-left: 0;
    margin-bottom: 0;
    vertical-align: middle; }
  .bootstrap .form-search .radio input[type="radio"],
  .bootstrap .form-search .checkbox input[type="checkbox"],
  .bootstrap .form-inline .radio input[type="radio"],
  .bootstrap .form-inline .checkbox input[type="checkbox"] {
    float: left;
    margin-right: 3px;
    margin-left: 0; }
  .bootstrap .control-group {
    margin-bottom: 10px; }
  .bootstrap legend + .control-group {
    margin-top: 20px;
    -webkit-margin-top-collapse: separate; }
  .bootstrap .form-horizontal .control-group {
    margin-bottom: 20px;
    *zoom: 1; }
    .bootstrap .form-horizontal .control-group:before, .bootstrap .form-horizontal .control-group:after {
      display: table;
      content: ""; }
    .bootstrap .form-horizontal .control-group:after {
      clear: both; }
  .bootstrap .form-horizontal .control-label {
    float: left;
    width: 140px;
    padding-top: 5px;
    text-align: right; }
  .bootstrap .form-horizontal .controls {
    *display: inline-block;
    *padding-left: 20px;
    margin-left: 160px;
    *margin-left: 0; }
    .bootstrap .form-horizontal .controls:first-child {
      *padding-left: 160px; }
  .bootstrap .form-horizontal .help-block {
    margin-top: 10px;
    margin-bottom: 0; }
  .bootstrap .form-horizontal .form-actions {
    padding-left: 160px; }
  .bootstrap table {
    max-width: 100%;
    background-color: transparent;
    border-collapse: collapse;
    border-spacing: 0; }
  .bootstrap .table {
    width: 100%;
    margin-bottom: 20px; }
    .bootstrap .table th,
    .bootstrap .table td {
      padding: 8px;
      line-height: 20px;
      text-align: left;
      vertical-align: top;
      border-top: 1px solid #dddddd; }
    .bootstrap .table th {
      font-weight: bold; }
    .bootstrap .table thead th {
      vertical-align: bottom; }
    .bootstrap .table caption + thead tr:first-child th,
    .bootstrap .table caption + thead tr:first-child td,
    .bootstrap .table colgroup + thead tr:first-child th,
    .bootstrap .table colgroup + thead tr:first-child td,
    .bootstrap .table thead:first-child tr:first-child th,
    .bootstrap .table thead:first-child tr:first-child td {
      border-top: 0; }
    .bootstrap .table tbody + tbody {
      border-top: 2px solid #dddddd; }
  .bootstrap .table-condensed th,
  .bootstrap .table-condensed td {
    padding: 4px 5px; }
  .bootstrap .table-bordered {
    border: 1px solid #dddddd;
    border-collapse: separate;
    *border-collapse: collapsed;
    border-left: 0;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px; }
    .bootstrap .table-bordered th,
    .bootstrap .table-bordered td {
      border-left: 1px solid #dddddd; }
    .bootstrap .table-bordered caption + thead tr:first-child th,
    .bootstrap .table-bordered caption + tbody tr:first-child th,
    .bootstrap .table-bordered caption + tbody tr:first-child td,
    .bootstrap .table-bordered colgroup + thead tr:first-child th,
    .bootstrap .table-bordered colgroup + tbody tr:first-child th,
    .bootstrap .table-bordered colgroup + tbody tr:first-child td,
    .bootstrap .table-bordered thead:first-child tr:first-child th,
    .bootstrap .table-bordered tbody:first-child tr:first-child th,
    .bootstrap .table-bordered tbody:first-child tr:first-child td {
      border-top: 0; }
    .bootstrap .table-bordered thead:first-child tr:first-child th:first-child,
    .bootstrap .table-bordered tbody:first-child tr:first-child td:first-child {
      -webkit-border-top-left-radius: 4px;
      border-top-left-radius: 4px;
      -moz-border-radius-topleft: 4px; }
    .bootstrap .table-bordered thead:first-child tr:first-child th:last-child,
    .bootstrap .table-bordered tbody:first-child tr:first-child td:last-child {
      -webkit-border-top-right-radius: 4px;
      border-top-right-radius: 4px;
      -moz-border-radius-topright: 4px; }
    .bootstrap .table-bordered thead:last-child tr:last-child th:first-child,
    .bootstrap .table-bordered tbody:last-child tr:last-child td:first-child {
      -webkit-border-radius: 0 0 0 4px;
      -moz-border-radius: 0 0 0 4px;
      border-radius: 0 0 0 4px;
      -webkit-border-bottom-left-radius: 4px;
      border-bottom-left-radius: 4px;
      -moz-border-radius-bottomleft: 4px; }
    .bootstrap .table-bordered thead:last-child tr:last-child th:last-child,
    .bootstrap .table-bordered tbody:last-child tr:last-child td:last-child {
      -webkit-border-bottom-right-radius: 4px;
      border-bottom-right-radius: 4px;
      -moz-border-radius-bottomright: 4px; }
  .bootstrap .table-striped tbody tr:nth-child(odd) td,
  .bootstrap .table-striped tbody tr:nth-child(odd) th {
    background-color: #f9f9f9; }
  .bootstrap .table tbody tr:hover td,
  .bootstrap .table tbody tr:hover th {
    background-color: whitesmoke; }
  .bootstrap table .span1 {
    float: none;
    width: 53px;
    margin-left: 0; }
  .bootstrap table .span2 {
    float: none;
    width: 134px;
    margin-left: 0; }
  .bootstrap table .span3 {
    float: none;
    width: 215px;
    margin-left: 0; }
  .bootstrap table .span4 {
    float: none;
    width: 296px;
    margin-left: 0; }
  .bootstrap table .span5 {
    float: none;
    width: 377px;
    margin-left: 0; }
  .bootstrap table .span6 {
    float: none;
    width: 458px;
    margin-left: 0; }
  .bootstrap table .span7 {
    float: none;
    width: 539px;
    margin-left: 0; }
  .bootstrap table .span8 {
    float: none;
    width: 620px;
    margin-left: 0; }
  .bootstrap table .span9 {
    float: none;
    width: 701px;
    margin-left: 0; }
  .bootstrap table .span10 {
    float: none;
    width: 782px;
    margin-left: 0; }
  .bootstrap table .span11 {
    float: none;
    width: 863px;
    margin-left: 0; }
  .bootstrap table .span12 {
    float: none;
    width: 944px;
    margin-left: 0; }
  .bootstrap table .span13 {
    float: none;
    width: 1025px;
    margin-left: 0; }
  .bootstrap table .span14 {
    float: none;
    width: 1106px;
    margin-left: 0; }
  .bootstrap table .span15 {
    float: none;
    width: 1187px;
    margin-left: 0; }
  .bootstrap table .span16 {
    float: none;
    width: 1268px;
    margin-left: 0; }
  .bootstrap table .span17 {
    float: none;
    width: 1349px;
    margin-left: 0; }
  .bootstrap table .span18 {
    float: none;
    width: 1430px;
    margin-left: 0; }
  .bootstrap table .span19 {
    float: none;
    width: 1511px;
    margin-left: 0; }
  .bootstrap table .span20 {
    float: none;
    width: 1592px;
    margin-left: 0; }
  .bootstrap table .span21 {
    float: none;
    width: 1673px;
    margin-left: 0; }
  .bootstrap table .span22 {
    float: none;
    width: 1754px;
    margin-left: 0; }
  .bootstrap table .span23 {
    float: none;
    width: 1835px;
    margin-left: 0; }
  .bootstrap table .span24 {
    float: none;
    width: 1916px;
    margin-left: 0; }
  .bootstrap [class^="icon-"],
  .bootstrap [class*=" icon-"] {
    display: inline-block;
    width: 14px;
    height: 14px;
    *margin-right: .3em;
    line-height: 14px;
    vertical-align: text-top;
    background-image: url("../img/glyphicons-halflings.png");
    background-position: 14px 14px;
    background-repeat: no-repeat; }
    .bootstrap [class^="icon-"]:last-child,
    .bootstrap [class*=" icon-"]:last-child {
      *margin-left: 0; }
  .bootstrap .icon-white {
    background-image: url("../img/glyphicons-halflings-white.png"); }
  .bootstrap .icon-glass {
    background-position: 0      0; }
  .bootstrap .icon-music {
    background-position: -24px 0; }
  .bootstrap .icon-search {
    background-position: -48px 0; }
  .bootstrap .icon-envelope {
    background-position: -72px 0; }
  .bootstrap .icon-heart {
    background-position: -96px 0; }
  .bootstrap .icon-star {
    background-position: -120px 0; }
  .bootstrap .icon-star-empty {
    background-position: -144px 0; }
  .bootstrap .icon-user {
    background-position: -168px 0; }
  .bootstrap .icon-film {
    background-position: -192px 0; }
  .bootstrap .icon-th-large {
    background-position: -216px 0; }
  .bootstrap .icon-th {
    background-position: -240px 0; }
  .bootstrap .icon-th-list {
    background-position: -264px 0; }
  .bootstrap .icon-ok {
    background-position: -288px 0; }
  .bootstrap .icon-remove {
    background-position: -312px 0; }
  .bootstrap .icon-zoom-in {
    background-position: -336px 0; }
  .bootstrap .icon-zoom-out {
    background-position: -360px 0; }
  .bootstrap .icon-off {
    background-position: -384px 0; }
  .bootstrap .icon-signal {
    background-position: -408px 0; }
  .bootstrap .icon-cog {
    background-position: -432px 0; }
  .bootstrap .icon-trash {
    background-position: -456px 0; }
  .bootstrap .icon-home {
    background-position: 0 -24px; }
  .bootstrap .icon-file {
    background-position: -24px -24px; }
  .bootstrap .icon-time {
    background-position: -48px -24px; }
  .bootstrap .icon-road {
    background-position: -72px -24px; }
  .bootstrap .icon-download-alt {
    background-position: -96px -24px; }
  .bootstrap .icon-download {
    background-position: -120px -24px; }
  .bootstrap .icon-upload {
    background-position: -144px -24px; }
  .bootstrap .icon-inbox {
    background-position: -168px -24px; }
  .bootstrap .icon-play-circle {
    background-position: -192px -24px; }
  .bootstrap .icon-repeat {
    background-position: -216px -24px; }
  .bootstrap .icon-refresh {
    background-position: -240px -24px; }
  .bootstrap .icon-list-alt {
    background-position: -264px -24px; }
  .bootstrap .icon-lock {
    background-position: -287px -24px; }
  .bootstrap .icon-flag {
    background-position: -312px -24px; }
  .bootstrap .icon-headphones {
    background-position: -336px -24px; }
  .bootstrap .icon-volume-off {
    background-position: -360px -24px; }
  .bootstrap .icon-volume-down {
    background-position: -384px -24px; }
  .bootstrap .icon-volume-up {
    background-position: -408px -24px; }
  .bootstrap .icon-qrcode {
    background-position: -432px -24px; }
  .bootstrap .icon-barcode {
    background-position: -456px -24px; }
  .bootstrap .icon-tag {
    background-position: 0 -48px; }
  .bootstrap .icon-tags {
    background-position: -25px -48px; }
  .bootstrap .icon-book {
    background-position: -48px -48px; }
  .bootstrap .icon-bookmark {
    background-position: -72px -48px; }
  .bootstrap .icon-print {
    background-position: -96px -48px; }
  .bootstrap .icon-camera {
    background-position: -120px -48px; }
  .bootstrap .icon-font {
    background-position: -144px -48px; }
  .bootstrap .icon-bold {
    background-position: -167px -48px; }
  .bootstrap .icon-italic {
    background-position: -192px -48px; }
  .bootstrap .icon-text-height {
    background-position: -216px -48px; }
  .bootstrap .icon-text-width {
    background-position: -240px -48px; }
  .bootstrap .icon-align-left {
    background-position: -264px -48px; }
  .bootstrap .icon-align-center {
    background-position: -288px -48px; }
  .bootstrap .icon-align-right {
    background-position: -312px -48px; }
  .bootstrap .icon-align-justify {
    background-position: -336px -48px; }
  .bootstrap .icon-list {
    background-position: -360px -48px; }
  .bootstrap .icon-indent-left {
    background-position: -384px -48px; }
  .bootstrap .icon-indent-right {
    background-position: -408px -48px; }
  .bootstrap .icon-facetime-video {
    background-position: -432px -48px; }
  .bootstrap .icon-picture {
    background-position: -456px -48px; }
  .bootstrap .icon-pencil {
    background-position: 0 -72px; }
  .bootstrap .icon-map-marker {
    background-position: -24px -72px; }
  .bootstrap .icon-adjust {
    background-position: -48px -72px; }
  .bootstrap .icon-tint {
    background-position: -72px -72px; }
  .bootstrap .icon-edit {
    background-position: -96px -72px; }
  .bootstrap .icon-share {
    background-position: -120px -72px; }
  .bootstrap .icon-check {
    background-position: -144px -72px; }
  .bootstrap .icon-move {
    background-position: -168px -72px; }
  .bootstrap .icon-step-backward {
    background-position: -192px -72px; }
  .bootstrap .icon-fast-backward {
    background-position: -216px -72px; }
  .bootstrap .icon-backward {
    background-position: -240px -72px; }
  .bootstrap .icon-play {
    background-position: -264px -72px; }
  .bootstrap .icon-pause {
    background-position: -288px -72px; }
  .bootstrap .icon-stop {
    background-position: -312px -72px; }
  .bootstrap .icon-forward {
    background-position: -336px -72px; }
  .bootstrap .icon-fast-forward {
    background-position: -360px -72px; }
  .bootstrap .icon-step-forward {
    background-position: -384px -72px; }
  .bootstrap .icon-eject {
    background-position: -408px -72px; }
  .bootstrap .icon-chevron-left {
    background-position: -432px -72px; }
  .bootstrap .icon-chevron-right {
    background-position: -456px -72px; }
  .bootstrap .icon-plus-sign {
    background-position: 0 -96px; }
  .bootstrap .icon-minus-sign {
    background-position: -24px -96px; }
  .bootstrap .icon-remove-sign {
    background-position: -48px -96px; }
  .bootstrap .icon-ok-sign {
    background-position: -72px -96px; }
  .bootstrap .icon-question-sign {
    background-position: -96px -96px; }
  .bootstrap .icon-info-sign {
    background-position: -120px -96px; }
  .bootstrap .icon-screenshot {
    background-position: -144px -96px; }
  .bootstrap .icon-remove-circle {
    background-position: -168px -96px; }
  .bootstrap .icon-ok-circle {
    background-position: -192px -96px; }
  .bootstrap .icon-ban-circle {
    background-position: -216px -96px; }
  .bootstrap .icon-arrow-left {
    background-position: -240px -96px; }
  .bootstrap .icon-arrow-right {
    background-position: -264px -96px; }
  .bootstrap .icon-arrow-up {
    background-position: -289px -96px; }
  .bootstrap .icon-arrow-down {
    background-position: -312px -96px; }
  .bootstrap .icon-share-alt {
    background-position: -336px -96px; }
  .bootstrap .icon-resize-full {
    background-position: -360px -96px; }
  .bootstrap .icon-resize-small {
    background-position: -384px -96px; }
  .bootstrap .icon-plus {
    background-position: -408px -96px; }
  .bootstrap .icon-minus {
    background-position: -433px -96px; }
  .bootstrap .icon-asterisk {
    background-position: -456px -96px; }
  .bootstrap .icon-exclamation-sign {
    background-position: 0 -120px; }
  .bootstrap .icon-gift {
    background-position: -24px -120px; }
  .bootstrap .icon-leaf {
    background-position: -48px -120px; }
  .bootstrap .icon-fire {
    background-position: -72px -120px; }
  .bootstrap .icon-eye-open {
    background-position: -96px -120px; }
  .bootstrap .icon-eye-close {
    background-position: -120px -120px; }
  .bootstrap .icon-warning-sign {
    background-position: -144px -120px; }
  .bootstrap .icon-plane {
    background-position: -168px -120px; }
  .bootstrap .icon-calendar {
    background-position: -192px -120px; }
  .bootstrap .icon-random {
    background-position: -216px -120px; }
  .bootstrap .icon-comment {
    background-position: -240px -120px; }
  .bootstrap .icon-magnet {
    background-position: -264px -120px; }
  .bootstrap .icon-chevron-up {
    background-position: -288px -120px; }
  .bootstrap .icon-chevron-down {
    background-position: -313px -119px; }
  .bootstrap .icon-retweet {
    background-position: -336px -120px; }
  .bootstrap .icon-shopping-cart {
    background-position: -360px -120px; }
  .bootstrap .icon-folder-close {
    background-position: -384px -120px; }
  .bootstrap .icon-folder-open {
    background-position: -408px -120px; }
  .bootstrap .icon-resize-vertical {
    background-position: -432px -119px; }
  .bootstrap .icon-resize-horizontal {
    background-position: -456px -118px; }
  .bootstrap .icon-hdd {
    background-position: 0 -144px; }
  .bootstrap .icon-bullhorn {
    background-position: -24px -144px; }
  .bootstrap .icon-bell {
    background-position: -48px -144px; }
  .bootstrap .icon-certificate {
    background-position: -72px -144px; }
  .bootstrap .icon-thumbs-up {
    background-position: -96px -144px; }
  .bootstrap .icon-thumbs-down {
    background-position: -120px -144px; }
  .bootstrap .icon-hand-right {
    background-position: -144px -144px; }
  .bootstrap .icon-hand-left {
    background-position: -168px -144px; }
  .bootstrap .icon-hand-up {
    background-position: -192px -144px; }
  .bootstrap .icon-hand-down {
    background-position: -216px -144px; }
  .bootstrap .icon-circle-arrow-right {
    background-position: -240px -144px; }
  .bootstrap .icon-circle-arrow-left {
    background-position: -264px -144px; }
  .bootstrap .icon-circle-arrow-up {
    background-position: -288px -144px; }
  .bootstrap .icon-circle-arrow-down {
    background-position: -312px -144px; }
  .bootstrap .icon-globe {
    background-position: -336px -144px; }
  .bootstrap .icon-wrench {
    background-position: -360px -144px; }
  .bootstrap .icon-tasks {
    background-position: -384px -144px; }
  .bootstrap .icon-filter {
    background-position: -408px -144px; }
  .bootstrap .icon-briefcase {
    background-position: -432px -144px; }
  .bootstrap .icon-fullscreen {
    background-position: -456px -144px; }
  .bootstrap .dropup,
  .bootstrap .dropdown {
    position: relative; }
  .bootstrap .dropdown-toggle {
    *margin-bottom: -3px; }
  .bootstrap .dropdown-toggle:active,
  .bootstrap .open .dropdown-toggle {
    outline: 0; }
  .bootstrap .caret {
    display: inline-block;
    width: 0;
    height: 0;
    vertical-align: top;
    border-top: 4px solid black;
    border-right: 4px solid transparent;
    border-left: 4px solid transparent;
    content: "";
    opacity: 0.3;
    filter: alpha(opacity=30); }
  .bootstrap .dropdown .caret {
    margin-top: 8px;
    margin-left: 2px; }
  .bootstrap .dropdown:hover .caret,
  .bootstrap .open .caret {
    opacity: 1;
    filter: alpha(opacity=100); }
  .bootstrap .dropdown-menu {
    position: absolute;
    top: 100%;
    left: 0;
    z-index: 1000;
    display: none;
    float: left;
    min-width: 160px;
    padding: 4px 0;
    margin: 1px 0 0;
    list-style: none;
    background-color: white;
    border: 1px solid #ccc;
    border: 1px solid rgba(0, 0, 0, 0.2);
    *border-right-width: 2px;
    *border-bottom-width: 2px;
    -webkit-border-radius: 5px;
    -moz-border-radius: 5px;
    border-radius: 5px;
    -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
    box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
    -webkit-background-clip: padding-box;
    -moz-background-clip: padding;
    background-clip: padding-box; }
    .bootstrap .dropdown-menu.pull-right {
      right: 0;
      left: auto; }
    .bootstrap .dropdown-menu .divider {
      *width: 100%;
      height: 1px;
      margin: 9px 1px;
      *margin: -5px 0 5px;
      overflow: hidden;
      background-color: #e5e5e5;
      border-bottom: 1px solid white; }
    .bootstrap .dropdown-menu a {
      display: block;
      padding: 3px 15px;
      clear: both;
      font-weight: normal;
      line-height: 20px;
      color: #333333;
      white-space: nowrap; }
  .bootstrap .dropdown-menu li > a:hover,
  .bootstrap .dropdown-menu .active > a,
  .bootstrap .dropdown-menu .active > a:hover {
    color: white;
    text-decoration: none;
    background-color: #008990; }
  .bootstrap .open {
    *z-index: 1000; }
    .bootstrap .open .dropdown-menu {
      display: block; }
  .bootstrap .pull-right .dropdown-menu {
    right: 0;
    left: auto; }
  .bootstrap .dropup .caret,
  .bootstrap .navbar-fixed-bottom .dropdown .caret {
    border-top: 0;
    border-bottom: 4px solid black;
    content: "\2191"; }
  .bootstrap .dropup .dropdown-menu,
  .bootstrap .navbar-fixed-bottom .dropdown .dropdown-menu {
    top: auto;
    bottom: 100%;
    margin-bottom: 1px; }
  .bootstrap .typeahead {
    margin-top: 2px;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px; }
  .bootstrap .well {
    min-height: 20px;
    padding: 19px;
    margin-bottom: 20px;
    background-color: #e6e6e6;
    border: 1px solid #eee;
    border: 1px solid rgba(0, 0, 0, 0.05);
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
    -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05); }
    .bootstrap .well blockquote {
      border-color: #ddd;
      border-color: rgba(0, 0, 0, 0.15); }
  .bootstrap .well-large {
    padding: 24px;
    -webkit-border-radius: 6px;
    -moz-border-radius: 6px;
    border-radius: 6px; }
  .bootstrap .well-small {
    padding: 0.5em 1em;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px; }
  .bootstrap .fade {
    opacity: 0;
    filter: alpha(opacity=0);
    -webkit-transition: opacity 0.15s linear;
    -moz-transition: opacity 0.15s linear;
    -ms-transition: opacity 0.15s linear;
    -o-transition: opacity 0.15s linear;
    transition: opacity 0.15s linear; }
    .bootstrap .fade.in {
      opacity: 1;
      filter: alpha(opacity=100); }
  .bootstrap .collapse {
    position: relative;
    height: 0;
    overflow: hidden;
    -webkit-transition: height 0.35s ease;
    -moz-transition: height 0.35s ease;
    -ms-transition: height 0.35s ease;
    -o-transition: height 0.35s ease;
    transition: height 0.35s ease; }
    .bootstrap .collapse.in {
      height: auto; }
  .bootstrap .close {
    float: right;
    font-size: 20px;
    font-weight: bold;
    line-height: 20px;
    color: black;
    text-shadow: 0 1px 0 white;
    opacity: 0.2;
    filter: alpha(opacity=20); }
    .bootstrap .close:hover {
      color: black;
      text-decoration: none;
      cursor: pointer;
      opacity: 0.4;
      filter: alpha(opacity=40); }
  .bootstrap button.close {
    padding: 0;
    cursor: pointer;
    background: transparent;
    border: 0;
    -webkit-appearance: none; }
  .bootstrap .btn {
    display: inline-block;
    *display: inline;
    *zoom: 1;
    padding: 4px 10px 4px;
    margin-bottom: 0;
    font-size: 15px;
    line-height: 20px;
    *line-height: 20px;
    color: #333333;
    text-align: center;
    text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
    vertical-align: middle;
    cursor: pointer;
    background-color: whitesmoke;
    background-image: -moz-linear-gradient(top, white, #e6e6e6);
    background-image: -ms-linear-gradient(top, white, #e6e6e6);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(white), to(#e6e6e6));
    background-image: -webkit-linear-gradient(top, white, #e6e6e6);
    background-image: -o-linear-gradient(top, white, #e6e6e6);
    background-image: linear-gradient(top, white, #e6e6e6);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fcfcfc', endColorstr='#e3e3e3', GradientType=0);
    border-color: #e6e6e6 #e6e6e6 #bfbfbf;
    border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
    *background-color: #e6e6e6;
    /* Darken IE7 buttons by default so they stand out more given they won't have borders */
    filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
    border: 1px solid #cccccc;
    *border: 0;
    border-bottom-color: #b3b3b3;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    *margin-left: .3em;
    -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
    -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
    box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05); }
    .bootstrap .btn:hover, .bootstrap .btn:active, .bootstrap .btn.active, .bootstrap .btn.disabled, .bootstrap .btn[disabled] {
      background-color: #e6e6e6;
      *background-color: #d9d9d9; }
    .bootstrap .btn:active, .bootstrap .btn.active {
      background-color: #cccccc \9; }
    .bootstrap .btn:first-child {
      *margin-left: 0; }
  .bootstrap .btn:hover {
    color: #333333;
    text-decoration: none;
    background-color: #e6e6e6;
    *background-color: #d9d9d9;
    /* Buttons in IE7 don't get borders, so darken on hover */
    background-position: 0 -15px;
    -webkit-transition: background-position 0.1s linear;
    -moz-transition: background-position 0.1s linear;
    -ms-transition: background-position 0.1s linear;
    -o-transition: background-position 0.1s linear;
    transition: background-position 0.1s linear; }
  .bootstrap .btn:focus {
    outline: thin dotted #333;
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px; }
  .bootstrap .btn.active,
  .bootstrap .btn:active {
    background-color: #e6e6e6;
    background-color: #d9d9d9 \9;
    background-image: none;
    outline: 0;
    -webkit-box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
    -moz-box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
    box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05); }
  .bootstrap .btn.disabled,
  .bootstrap .btn[disabled] {
    cursor: default;
    background-color: #e6e6e6;
    background-image: none;
    opacity: 0.65;
    filter: alpha(opacity=65);
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none; }
  .bootstrap .btn-large {
    padding: 9px 14px;
    font-size: 17px;
    line-height: normal;
    -webkit-border-radius: 5px;
    -moz-border-radius: 5px;
    border-radius: 5px; }
  .bootstrap .btn-large [class^="icon-"] {
    margin-top: 1px; }
  .bootstrap .btn-small {
    padding: 5px 9px;
    font-size: 13px;
    line-height: 18px; }
  .bootstrap .btn-small [class^="icon-"] {
    margin-top: -1px; }
  .bootstrap .btn-mini {
    padding: 2px 6px;
    font-size: 13px;
    line-height: 16px; }
  .bootstrap .btn-primary,
  .bootstrap .btn-primary:hover,
  .bootstrap .btn-warning,
  .bootstrap .btn-warning:hover,
  .bootstrap .btn-danger,
  .bootstrap .btn-danger:hover,
  .bootstrap .btn-success,
  .bootstrap .btn-success:hover,
  .bootstrap .btn-info,
  .bootstrap .btn-info:hover,
  .bootstrap .btn-inverse,
  .bootstrap .btn-inverse:hover {
    color: white;
    text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25); }
  .bootstrap .btn-primary.active,
  .bootstrap .btn-warning.active,
  .bootstrap .btn-danger.active,
  .bootstrap .btn-success.active,
  .bootstrap .btn-info.active,
  .bootstrap .btn-inverse.active {
    color: rgba(255, 255, 255, 0.75); }
  .bootstrap .btn {
    border-color: #ccc;
    border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25); }
  .bootstrap .btn-primary {
    background-color: #007a90;
    background-image: -moz-linear-gradient(top, #008990, #006590);
    background-image: -ms-linear-gradient(top, #008990, #006590);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#008990), to(#006590));
    background-image: -webkit-linear-gradient(top, #008990, #006590);
    background-image: -o-linear-gradient(top, #008990, #006590);
    background-image: linear-gradient(top, #008990, #006590);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00848b', endColorstr='#00618b', GradientType=0);
    border-color: #006590 #006590 #002f44;
    border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
    *background-color: #006590;
    /* Darken IE7 buttons by default so they stand out more given they won't have borders */
    filter: progid:DXImageTransform.Microsoft.gradient(enabled=false); }
    .bootstrap .btn-primary:hover, .bootstrap .btn-primary:active, .bootstrap .btn-primary.active, .bootstrap .btn-primary.disabled, .bootstrap .btn-primary[disabled] {
      background-color: #006590;
      *background-color: #005376; }
    .bootstrap .btn-primary:active, .bootstrap .btn-primary.active {
      background-color: #00415d \9; }
  .bootstrap .btn-warning {
    background-color: #f9a732;
    background-image: -moz-linear-gradient(top, #fbb450, #f89406);
    background-image: -ms-linear-gradient(top, #fbb450, #f89406);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#fbb450), to(#f89406));
    background-image: -webkit-linear-gradient(top, #fbb450, #f89406);
    background-image: -o-linear-gradient(top, #fbb450, #f89406);
    background-image: linear-gradient(top, #fbb450, #f89406);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fbb24b', endColorstr='#f39106', GradientType=0);
    border-color: #f89406 #f89406 #ad6704;
    border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
    *background-color: #f89406;
    /* Darken IE7 buttons by default so they stand out more given they won't have borders */
    filter: progid:DXImageTransform.Microsoft.gradient(enabled=false); }
    .bootstrap .btn-warning:hover, .bootstrap .btn-warning:active, .bootstrap .btn-warning.active, .bootstrap .btn-warning.disabled, .bootstrap .btn-warning[disabled] {
      background-color: #f89406;
      *background-color: #df8505; }
    .bootstrap .btn-warning:active, .bootstrap .btn-warning.active {
      background-color: #c67605 \9; }
  .bootstrap .btn-danger {
    background-color: #da4e49;
    background-image: -moz-linear-gradient(top, #ee5f5b, #bd362f);
    background-image: -ms-linear-gradient(top, #ee5f5b, #bd362f);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ee5f5b), to(#bd362f));
    background-image: -webkit-linear-gradient(top, #ee5f5b, #bd362f);
    background-image: -o-linear-gradient(top, #ee5f5b, #bd362f);
    background-image: linear-gradient(top, #ee5f5b, #bd362f);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ee5a56', endColorstr='#b9352e', GradientType=0);
    border-color: #bd362f #bd362f #802420;
    border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
    *background-color: #bd362f;
    /* Darken IE7 buttons by default so they stand out more given they won't have borders */
    filter: progid:DXImageTransform.Microsoft.gradient(enabled=false); }
    .bootstrap .btn-danger:hover, .bootstrap .btn-danger:active, .bootstrap .btn-danger.active, .bootstrap .btn-danger.disabled, .bootstrap .btn-danger[disabled] {
      background-color: #bd362f;
      *background-color: #a9302a; }
    .bootstrap .btn-danger:active, .bootstrap .btn-danger.active {
      background-color: #942a25 \9; }
  .bootstrap .btn-success {
    background-color: #5bb65b;
    background-image: -moz-linear-gradient(top, #62c462, #51a351);
    background-image: -ms-linear-gradient(top, #62c462, #51a351);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#62c462), to(#51a351));
    background-image: -webkit-linear-gradient(top, #62c462, #51a351);
    background-image: -o-linear-gradient(top, #62c462, #51a351);
    background-image: linear-gradient(top, #62c462, #51a351);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#5ec35e', endColorstr='#4fa04f', GradientType=0);
    border-color: #51a351 #51a351 #387038;
    border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
    *background-color: #51a351;
    /* Darken IE7 buttons by default so they stand out more given they won't have borders */
    filter: progid:DXImageTransform.Microsoft.gradient(enabled=false); }
    .bootstrap .btn-success:hover, .bootstrap .btn-success:active, .bootstrap .btn-success.active, .bootstrap .btn-success.disabled, .bootstrap .btn-success[disabled] {
      background-color: #51a351;
      *background-color: #499249; }
    .bootstrap .btn-success:active, .bootstrap .btn-success.active {
      background-color: #408140 \9; }
  .bootstrap .btn-info {
    background-color: #49afcd;
    background-image: -moz-linear-gradient(top, #5bc0de, #2f96b4);
    background-image: -ms-linear-gradient(top, #5bc0de, #2f96b4);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#5bc0de), to(#2f96b4));
    background-image: -webkit-linear-gradient(top, #5bc0de, #2f96b4);
    background-image: -o-linear-gradient(top, #5bc0de, #2f96b4);
    background-image: linear-gradient(top, #5bc0de, #2f96b4);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#57bedd', endColorstr='#2e93b0', GradientType=0);
    border-color: #2f96b4 #2f96b4 #1f6377;
    border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
    *background-color: #2f96b4;
    /* Darken IE7 buttons by default so they stand out more given they won't have borders */
    filter: progid:DXImageTransform.Microsoft.gradient(enabled=false); }
    .bootstrap .btn-info:hover, .bootstrap .btn-info:active, .bootstrap .btn-info.active, .bootstrap .btn-info.disabled, .bootstrap .btn-info[disabled] {
      background-color: #2f96b4;
      *background-color: #2a85a0; }
    .bootstrap .btn-info:active, .bootstrap .btn-info.active {
      background-color: #24748c \9; }
  .bootstrap .btn-inverse {
    background-color: #404040;
    background-image: -moz-linear-gradient(top, #555555, #222222);
    background-image: -ms-linear-gradient(top, #555555, #222222);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#555555), to(#222222));
    background-image: -webkit-linear-gradient(top, #555555, #222222);
    background-image: -o-linear-gradient(top, #555555, #222222);
    background-image: linear-gradient(top, #555555, #222222);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#525252', endColorstr='#1f1f1f', GradientType=0);
    border-color: #222222 #222222 black;
    border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
    *background-color: #222222;
    /* Darken IE7 buttons by default so they stand out more given they won't have borders */
    filter: progid:DXImageTransform.Microsoft.gradient(enabled=false); }
    .bootstrap .btn-inverse:hover, .bootstrap .btn-inverse:active, .bootstrap .btn-inverse.active, .bootstrap .btn-inverse.disabled, .bootstrap .btn-inverse[disabled] {
      background-color: #222222;
      *background-color: #151515; }
    .bootstrap .btn-inverse:active, .bootstrap .btn-inverse.active {
      background-color: #090909 \9; }
  .bootstrap .btn-trib {
    background-color: #edbb13;
    background-image: -moz-linear-gradient(top, #ffcc20, #d3a200);
    background-image: -ms-linear-gradient(top, #ffcc20, #d3a200);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffcc20), to(#d3a200));
    background-image: -webkit-linear-gradient(top, #ffcc20, #d3a200);
    background-image: -o-linear-gradient(top, #ffcc20, #d3a200);
    background-image: linear-gradient(top, #ffcc20, #d3a200);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffcb1b', endColorstr='#cd9e00', GradientType=0);
    border-color: #d3a200 #d3a200 #866700;
    border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
    *background-color: #d3a200;
    /* Darken IE7 buttons by default so they stand out more given they won't have borders */
    filter: progid:DXImageTransform.Microsoft.gradient(enabled=false); }
    .bootstrap .btn-trib:hover, .bootstrap .btn-trib:active, .bootstrap .btn-trib.active, .bootstrap .btn-trib.disabled, .bootstrap .btn-trib[disabled] {
      background-color: #d3a200;
      *background-color: #b98f00; }
    .bootstrap .btn-trib:active, .bootstrap .btn-trib.active {
      background-color: #a07b00 \9; }
  .bootstrap .btn-facebook {
    background-color: #395694;
    background-image: -moz-linear-gradient(top, #4264aa, #2d4373);
    background-image: -ms-linear-gradient(top, #4264aa, #2d4373);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#4264aa), to(#2d4373));
    background-image: -webkit-linear-gradient(top, #4264aa, #2d4373);
    background-image: -o-linear-gradient(top, #4264aa, #2d4373);
    background-image: linear-gradient(top, #4264aa, #2d4373);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#4162a7', endColorstr='#2b4170', GradientType=0);
    border-color: #2d4373 #2d4373 #17233c;
    border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
    *background-color: #2d4373;
    /* Darken IE7 buttons by default so they stand out more given they won't have borders */
    filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
    color: #eeeeee;
    text-shadow: 0 0 0; }
    .bootstrap .btn-facebook:hover, .bootstrap .btn-facebook:active, .bootstrap .btn-facebook.active, .bootstrap .btn-facebook.disabled, .bootstrap .btn-facebook[disabled] {
      background-color: #2d4373;
      *background-color: #263961; }
    .bootstrap .btn-facebook:active, .bootstrap .btn-facebook.active {
      background-color: #1e2e4f \9; }
    .bootstrap .btn-facebook:hover {
      color: white; }
  .bootstrap .btn-twitter {
    background-color: #3b96ff;
    background-image: -moz-linear-gradient(top, #5aa7ff, #0d7eff);
    background-image: -ms-linear-gradient(top, #5aa7ff, #0d7eff);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#5aa7ff), to(#0d7eff));
    background-image: -webkit-linear-gradient(top, #5aa7ff, #0d7eff);
    background-image: -o-linear-gradient(top, #5aa7ff, #0d7eff);
    background-image: linear-gradient(top, #5aa7ff, #0d7eff);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#54a4ff', endColorstr='#087bff', GradientType=0);
    border-color: #0d7eff #0d7eff #0059c0;
    border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
    *background-color: #0d7eff;
    /* Darken IE7 buttons by default so they stand out more given they won't have borders */
    filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
    color: #eeeeee;
    text-shadow: 0 0 0; }
    .bootstrap .btn-twitter:hover, .bootstrap .btn-twitter:active, .bootstrap .btn-twitter.active, .bootstrap .btn-twitter.disabled, .bootstrap .btn-twitter[disabled] {
      background-color: #0d7eff;
      *background-color: #0071f3; }
    .bootstrap .btn-twitter:active, .bootstrap .btn-twitter.active {
      background-color: #0065d9 \9; }
    .bootstrap .btn-twitter:hover {
      color: white; }
  .bootstrap button.btn,
  .bootstrap input[type="submit"].btn {
    *padding-top: 2px;
    *padding-bottom: 2px; }
    .bootstrap button.btn::-moz-focus-inner,
    .bootstrap input[type="submit"].btn::-moz-focus-inner {
      padding: 0;
      border: 0; }
    .bootstrap button.btn.btn-large,
    .bootstrap input[type="submit"].btn.btn-large {
      *padding-top: 7px;
      *padding-bottom: 7px; }
    .bootstrap button.btn.btn-small,
    .bootstrap input[type="submit"].btn.btn-small {
      *padding-top: 3px;
      *padding-bottom: 3px; }
    .bootstrap button.btn.btn-mini,
    .bootstrap input[type="submit"].btn.btn-mini {
      *padding-top: 1px;
      *padding-bottom: 1px; }
  .bootstrap .btn-group {
    position: relative;
    *zoom: 1;
    *margin-left: .3em; }
    .bootstrap .btn-group:before, .bootstrap .btn-group:after {
      display: table;
      content: ""; }
    .bootstrap .btn-group:after {
      clear: both; }
    .bootstrap .btn-group:first-child {
      *margin-left: 0; }
  .bootstrap .btn-group + .btn-group {
    margin-left: 5px; }
  .bootstrap .btn-toolbar {
    margin-top: 10px;
    margin-bottom: 10px; }
    .bootstrap .btn-toolbar .btn-group {
      display: inline-block;
      *display: inline;
      *zoom: 1; }
  .bootstrap .btn-group > .btn {
    position: relative;
    float: left;
    margin-left: -1px;
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    border-radius: 0; }
  .bootstrap .btn-group > .btn:first-child {
    margin-left: 0;
    -webkit-border-top-left-radius: 4px;
    -moz-border-radius-topleft: 4px;
    border-top-left-radius: 4px;
    -webkit-border-bottom-left-radius: 4px;
    -moz-border-radius-bottomleft: 4px;
    border-bottom-left-radius: 4px; }
  .bootstrap .btn-group > .btn:last-child,
  .bootstrap .btn-group > .dropdown-toggle {
    -webkit-border-top-right-radius: 4px;
    -moz-border-radius-topright: 4px;
    border-top-right-radius: 4px;
    -webkit-border-bottom-right-radius: 4px;
    -moz-border-radius-bottomright: 4px;
    border-bottom-right-radius: 4px; }
  .bootstrap .btn-group > .btn.large:first-child {
    margin-left: 0;
    -webkit-border-top-left-radius: 6px;
    -moz-border-radius-topleft: 6px;
    border-top-left-radius: 6px;
    -webkit-border-bottom-left-radius: 6px;
    -moz-border-radius-bottomleft: 6px;
    border-bottom-left-radius: 6px; }
  .bootstrap .btn-group > .btn.large:last-child,
  .bootstrap .btn-group > .large.dropdown-toggle {
    -webkit-border-top-right-radius: 6px;
    -moz-border-radius-topright: 6px;
    border-top-right-radius: 6px;
    -webkit-border-bottom-right-radius: 6px;
    -moz-border-radius-bottomright: 6px;
    border-bottom-right-radius: 6px; }
  .bootstrap .btn-group > .btn:hover,
  .bootstrap .btn-group > .btn:focus,
  .bootstrap .btn-group > .btn:active,
  .bootstrap .btn-group > .btn.active {
    z-index: 2; }
  .bootstrap .btn-group .dropdown-toggle:active,
  .bootstrap .btn-group.open .dropdown-toggle {
    outline: 0; }
  .bootstrap .btn-group > .dropdown-toggle {
    padding-left: 8px;
    padding-right: 8px;
    -webkit-box-shadow: inset 1px 0 0 rgba(255, 255, 255, 0.125), inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
    -moz-box-shadow: inset 1px 0 0 rgba(255, 255, 255, 0.125), inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
    box-shadow: inset 1px 0 0 rgba(255, 255, 255, 0.125), inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
    *padding-top: 4px;
    *padding-bottom: 4px; }
  .bootstrap .btn-group > .btn-mini.dropdown-toggle {
    padding-left: 5px;
    padding-right: 5px; }
  .bootstrap .btn-group > .btn-small.dropdown-toggle {
    *padding-top: 4px;
    *padding-bottom: 4px; }
  .bootstrap .btn-group > .btn-large.dropdown-toggle {
    padding-left: 12px;
    padding-right: 12px; }
  .bootstrap .btn-group.open .dropdown-toggle {
    background-image: none;
    -webkit-box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
    -moz-box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05);
    box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.15), 0 1px 2px rgba(0, 0, 0, 0.05); }
  .bootstrap .btn-group.open .btn.dropdown-toggle {
    background-color: #e6e6e6; }
  .bootstrap .btn-group.open .btn-primary.dropdown-toggle {
    background-color: #006590; }
  .bootstrap .btn-group.open .btn-warning.dropdown-toggle {
    background-color: #f89406; }
  .bootstrap .btn-group.open .btn-danger.dropdown-toggle {
    background-color: #bd362f; }
  .bootstrap .btn-group.open .btn-success.dropdown-toggle {
    background-color: #51a351; }
  .bootstrap .btn-group.open .btn-info.dropdown-toggle {
    background-color: #2f96b4; }
  .bootstrap .btn-group.open .btn-inverse.dropdown-toggle {
    background-color: #222222; }
  .bootstrap .btn .caret {
    margin-top: 7px;
    margin-left: 0; }
  .bootstrap .btn:hover .caret,
  .bootstrap .open.btn-group .caret {
    opacity: 1;
    filter: alpha(opacity=100); }
  .bootstrap .btn-mini .caret {
    margin-top: 5px; }
  .bootstrap .btn-small .caret {
    margin-top: 6px; }
  .bootstrap .btn-large .caret {
    margin-top: 6px;
    border-left-width: 5px;
    border-right-width: 5px;
    border-top-width: 5px; }
  .bootstrap .dropup .btn-large .caret {
    border-bottom: 5px solid black;
    border-top: 0; }
  .bootstrap .btn-primary .caret,
  .bootstrap .btn-warning .caret,
  .bootstrap .btn-danger .caret,
  .bootstrap .btn-info .caret,
  .bootstrap .btn-success .caret,
  .bootstrap .btn-inverse .caret {
    border-top-color: white;
    border-bottom-color: white;
    opacity: 0.75;
    filter: alpha(opacity=75); }
  .bootstrap .alert {
    padding: 8px 35px 8px 14px;
    margin-bottom: 20px;
    text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
    background-color: #fcf8e3;
    border: 1px solid #fbeed5;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    color: #c09853; }
  .bootstrap .alert-heading {
    color: inherit; }
  .bootstrap .alert .close {
    position: relative;
    top: -2px;
    right: -21px;
    line-height: 18px; }
  .bootstrap .alert-success {
    background-color: #dff0d8;
    border-color: #d6e9c6;
    color: #468847; }
  .bootstrap .alert-danger,
  .bootstrap .alert-error {
    background-color: #f2dede;
    border-color: #eed3d7;
    color: #b94a48; }
  .bootstrap .alert-info {
    background-color: #d9edf7;
    border-color: #bce8f1;
    color: #3a87ad; }
  .bootstrap .alert-block {
    padding-top: 14px;
    padding-bottom: 14px; }
  .bootstrap .alert-block > p,
  .bootstrap .alert-block > ul {
    margin-bottom: 0; }
  .bootstrap .alert-block p + p {
    margin-top: 5px; }
  .bootstrap .nav {
    margin-left: 0;
    margin-bottom: 20px;
    list-style: none; }
  .bootstrap .nav > li > a {
    display: block; }
  .bootstrap .nav > li > a:hover {
    text-decoration: none;
    background-color: #eeeeee; }
  .bootstrap .nav > .pull-right {
    float: right; }
  .bootstrap .nav .nav-header {
    display: block;
    padding: 3px 15px;
    font-size: 11px;
    font-weight: bold;
    line-height: 20px;
    color: #999999;
    text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
    text-transform: uppercase; }
  .bootstrap .nav li + .nav-header {
    margin-top: 9px; }
  .bootstrap .nav-list {
    padding-left: 15px;
    padding-right: 15px;
    margin-bottom: 0; }
  .bootstrap .nav-list > li > a,
  .bootstrap .nav-list .nav-header {
    margin-left: -15px;
    margin-right: -15px;
    text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5); }
  .bootstrap .nav-list > li > a {
    padding: 3px 15px; }
  .bootstrap .nav-list > .active > a,
  .bootstrap .nav-list > .active > a:hover {
    color: white;
    text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.2);
    background-color: #008990; }
  .bootstrap .nav-list [class^="icon-"] {
    margin-right: 2px; }
  .bootstrap .nav-list .divider {
    *width: 100%;
    height: 1px;
    margin: 9px 1px;
    *margin: -5px 0 5px;
    overflow: hidden;
    background-color: #e5e5e5;
    border-bottom: 1px solid white; }
  .bootstrap .nav-tabs,
  .bootstrap .nav-pills {
    *zoom: 1; }
    .bootstrap .nav-tabs:before, .bootstrap .nav-tabs:after,
    .bootstrap .nav-pills:before,
    .bootstrap .nav-pills:after {
      display: table;
      content: ""; }
    .bootstrap .nav-tabs:after,
    .bootstrap .nav-pills:after {
      clear: both; }
  .bootstrap .nav-tabs > li,
  .bootstrap .nav-pills > li {
    float: left; }
  .bootstrap .nav-tabs > li > a,
  .bootstrap .nav-pills > li > a {
    padding-right: 12px;
    padding-left: 12px;
    margin-right: 2px;
    line-height: 14px; }
  .bootstrap .nav-tabs {
    border-bottom: 1px solid #ddd; }
  .bootstrap .nav-tabs > li {
    margin-bottom: -1px; }
  .bootstrap .nav-tabs > li > a {
    padding-top: 8px;
    padding-bottom: 8px;
    line-height: 20px;
    border: 1px solid transparent;
    -webkit-border-radius: 4px 4px 0 0;
    -moz-border-radius: 4px 4px 0 0;
    border-radius: 4px 4px 0 0; }
    .bootstrap .nav-tabs > li > a:hover {
      border-color: #eeeeee #eeeeee #dddddd; }
  .bootstrap .nav-tabs > .active > a,
  .bootstrap .nav-tabs > .active > a:hover {
    color: #555555;
    background-color: white;
    border: 1px solid #ddd;
    border-bottom-color: transparent;
    cursor: default; }
  .bootstrap .nav-pills > li > a {
    padding-top: 8px;
    padding-bottom: 8px;
    margin-top: 2px;
    margin-bottom: 2px;
    -webkit-border-radius: 5px;
    -moz-border-radius: 5px;
    border-radius: 5px; }
  .bootstrap .nav-pills > .active > a,
  .bootstrap .nav-pills > .active > a:hover {
    color: white;
    background-color: #008990; }
  .bootstrap .nav-stacked > li {
    float: none; }
  .bootstrap .nav-stacked > li > a {
    margin-right: 0; }
  .bootstrap .nav-tabs.nav-stacked {
    border-bottom: 0; }
  .bootstrap .nav-tabs.nav-stacked > li > a {
    border: 1px solid #ddd;
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    border-radius: 0; }
  .bootstrap .nav-tabs.nav-stacked > li:first-child > a {
    -webkit-border-radius: 4px 4px 0 0;
    -moz-border-radius: 4px 4px 0 0;
    border-radius: 4px 4px 0 0; }
  .bootstrap .nav-tabs.nav-stacked > li:last-child > a {
    -webkit-border-radius: 0 0 4px 4px;
    -moz-border-radius: 0 0 4px 4px;
    border-radius: 0 0 4px 4px; }
  .bootstrap .nav-tabs.nav-stacked > li > a:hover {
    border-color: #ddd;
    z-index: 2; }
  .bootstrap .nav-pills.nav-stacked > li > a {
    margin-bottom: 3px; }
  .bootstrap .nav-pills.nav-stacked > li:last-child > a {
    margin-bottom: 1px; }
  .bootstrap .nav-tabs .dropdown-menu {
    -webkit-border-radius: 0 0 5px 5px;
    -moz-border-radius: 0 0 5px 5px;
    border-radius: 0 0 5px 5px; }
  .bootstrap .nav-pills .dropdown-menu {
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px; }
  .bootstrap .nav-tabs .dropdown-toggle .caret,
  .bootstrap .nav-pills .dropdown-toggle .caret {
    border-top-color: #008990;
    border-bottom-color: #008990;
    margin-top: 6px; }
  .bootstrap .nav-tabs .dropdown-toggle:hover .caret,
  .bootstrap .nav-pills .dropdown-toggle:hover .caret {
    border-top-color: #004044;
    border-bottom-color: #004044; }
  .bootstrap .nav-tabs .active .dropdown-toggle .caret,
  .bootstrap .nav-pills .active .dropdown-toggle .caret {
    border-top-color: #333333;
    border-bottom-color: #333333; }
  .bootstrap .nav > .dropdown.active > a:hover {
    color: black;
    cursor: pointer; }
  .bootstrap .nav-tabs .open .dropdown-toggle,
  .bootstrap .nav-pills .open .dropdown-toggle,
  .bootstrap .nav > li.dropdown.open.active > a:hover {
    color: white;
    background-color: #999999;
    border-color: #999999; }
  .bootstrap .nav li.dropdown.open .caret,
  .bootstrap .nav li.dropdown.open.active .caret,
  .bootstrap .nav li.dropdown.open a:hover .caret {
    border-top-color: white;
    border-bottom-color: white;
    opacity: 1;
    filter: alpha(opacity=100); }
  .bootstrap .tabs-stacked .open > a:hover {
    border-color: #999999; }
  .bootstrap .tabbable {
    *zoom: 1; }
    .bootstrap .tabbable:before, .bootstrap .tabbable:after {
      display: table;
      content: ""; }
    .bootstrap .tabbable:after {
      clear: both; }
  .bootstrap .tab-content {
    overflow: auto; }
  .bootstrap .tabs-below > .nav-tabs,
  .bootstrap .tabs-right > .nav-tabs,
  .bootstrap .tabs-left > .nav-tabs {
    border-bottom: 0; }
  .bootstrap .tab-content > .tab-pane,
  .bootstrap .pill-content > .pill-pane {
    display: none; }
  .bootstrap .tab-content > .active,
  .bootstrap .pill-content > .active {
    display: block; }
  .bootstrap .tabs-below > .nav-tabs {
    border-top: 1px solid #ddd; }
  .bootstrap .tabs-below > .nav-tabs > li {
    margin-top: -1px;
    margin-bottom: 0; }
  .bootstrap .tabs-below > .nav-tabs > li > a {
    -webkit-border-radius: 0 0 4px 4px;
    -moz-border-radius: 0 0 4px 4px;
    border-radius: 0 0 4px 4px; }
    .bootstrap .tabs-below > .nav-tabs > li > a:hover {
      border-bottom-color: transparent;
      border-top-color: #ddd; }
  .bootstrap .tabs-below > .nav-tabs > .active > a,
  .bootstrap .tabs-below > .nav-tabs > .active > a:hover {
    border-color: transparent #ddd #ddd #ddd; }
  .bootstrap .tabs-left > .nav-tabs > li,
  .bootstrap .tabs-right > .nav-tabs > li {
    float: none; }
  .bootstrap .tabs-left > .nav-tabs > li > a,
  .bootstrap .tabs-right > .nav-tabs > li > a {
    min-width: 74px;
    margin-right: 0;
    margin-bottom: 3px; }
  .bootstrap .tabs-left > .nav-tabs {
    float: left;
    margin-right: 19px;
    border-right: 1px solid #ddd; }
  .bootstrap .tabs-left > .nav-tabs > li > a {
    margin-right: -1px;
    -webkit-border-radius: 4px 0 0 4px;
    -moz-border-radius: 4px 0 0 4px;
    border-radius: 4px 0 0 4px; }
  .bootstrap .tabs-left > .nav-tabs > li > a:hover {
    border-color: #eeeeee #dddddd #eeeeee #eeeeee; }
  .bootstrap .tabs-left > .nav-tabs .active > a,
  .bootstrap .tabs-left > .nav-tabs .active > a:hover {
    border-color: #ddd transparent #ddd #ddd;
    *border-right-color: white; }
  .bootstrap .tabs-right > .nav-tabs {
    float: right;
    margin-left: 19px;
    border-left: 1px solid #ddd; }
  .bootstrap .tabs-right > .nav-tabs > li > a {
    margin-left: -1px;
    -webkit-border-radius: 0 4px 4px 0;
    -moz-border-radius: 0 4px 4px 0;
    border-radius: 0 4px 4px 0; }
  .bootstrap .tabs-right > .nav-tabs > li > a:hover {
    border-color: #eeeeee #eeeeee #eeeeee #dddddd; }
  .bootstrap .tabs-right > .nav-tabs .active > a,
  .bootstrap .tabs-right > .nav-tabs .active > a:hover {
    border-color: #ddd #ddd #ddd transparent;
    *border-left-color: white; }
  .bootstrap .navbar {
    *position: relative;
    *z-index: 2;
    overflow: visible;
    margin-bottom: 20px; }
  .bootstrap .navbar-inner {
    font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
    min-height: 30px;
    background-color: #404040;
    background-image: -moz-linear-gradient(top, #555555, #222222);
    background-image: -ms-linear-gradient(top, #555555, #222222);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#555555), to(#222222));
    background-image: -webkit-linear-gradient(top, #555555, #222222);
    background-image: -o-linear-gradient(top, #555555, #222222);
    background-image: linear-gradient(top, #555555, #222222);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#525252', endColorstr='#1f1f1f', GradientType=0); }
  .bootstrap .navbar .container {
    width: auto; }
  .bootstrap .nav-collapse.collapse {
    height: auto; }
  .bootstrap .navbar {
    color: #eeeeee;
    margin-bottom: 10px; }
    .bootstrap .navbar .brand:hover {
      text-decoration: none; }
    .bootstrap .navbar .brand {
      float: left;
      display: block;
      padding: 3px 20px 7px;
      margin-left: -20px;
      font-size: 20px;
      font-weight: 200;
      line-height: 1;
      color: #eeeeee; }
    .bootstrap .navbar .navbar-text {
      margin-bottom: 0;
      line-height: 30px; }
    .bootstrap .navbar .navbar-link {
      color: #eeeeee; }
      .bootstrap .navbar .navbar-link:hover {
        color: #ffcc20; }
    .bootstrap .navbar .btn,
    .bootstrap .navbar .btn-group {
      margin-top: 0px; }
    .bootstrap .navbar .btn-group .btn {
      margin: 0; }
  .bootstrap .navbar-form {
    margin-bottom: 0;
    *zoom: 1; }
    .bootstrap .navbar-form:before, .bootstrap .navbar-form:after {
      display: table;
      content: ""; }
    .bootstrap .navbar-form:after {
      clear: both; }
    .bootstrap .navbar-form input,
    .bootstrap .navbar-form select,
    .bootstrap .navbar-form .radio,
    .bootstrap .navbar-form .checkbox {
      margin-top: 0px; }
    .bootstrap .navbar-form input,
    .bootstrap .navbar-form select {
      display: inline-block;
      margin-bottom: 0; }
    .bootstrap .navbar-form input[type="image"],
    .bootstrap .navbar-form input[type="checkbox"],
    .bootstrap .navbar-form input[type="radio"] {
      margin-top: 3px; }
    .bootstrap .navbar-form .input-append,
    .bootstrap .navbar-form .input-prepend {
      margin-top: 6px;
      white-space: nowrap; }
      .bootstrap .navbar-form .input-append input,
      .bootstrap .navbar-form .input-prepend input {
        margin-top: 0; }
  .bootstrap .navbar-search {
    position: relative;
    float: left;
    margin-top: 1px;
    margin-bottom: 0;
    margin-top: 3px; }
    .bootstrap .navbar-search .search-query {
      -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1), 0 1px 0 rgba(255, 255, 255, 0.15);
      -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1), 0 1px 0 rgba(255, 255, 255, 0.15);
      box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1), 0 1px 0 rgba(255, 255, 255, 0.15);
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
      font-size: 13px;
      font-weight: normal;
      line-height: 1;
      background-color: #fafafa;
      border: 1px solid #adadad;
      color: #333333;
      height: auto;
      margin-bottom: 0;
      padding: 3px 9px; }
      .bootstrap .navbar-search .search-query :-moz-placeholder {
        color: #555555; }
      .bootstrap .navbar-search .search-query :-ms-input-placeholder {
        color: #555555; }
      .bootstrap .navbar-search .search-query ::-webkit-input-placeholder {
        color: #555555; }
      .bootstrap .navbar-search .search-query:focus, .bootstrap .navbar-search .search-query.focused {
        padding: 5px 10px;
        color: #333333;
        text-shadow: 0 1px 0 white;
        background-color: white;
        border: 0;
        -webkit-box-shadow: 0 0 3px rgba(0, 0, 0, 0.15);
        -moz-box-shadow: 0 0 3px rgba(0, 0, 0, 0.15);
        box-shadow: 0 0 3px rgba(0, 0, 0, 0.15);
        outline: 0; }
  .bootstrap .navbar-fixed-top,
  .bootstrap .navbar-fixed-bottom {
    position: fixed;
    right: 0;
    left: 0;
    z-index: 1030;
    margin-bottom: 0; }
  .bootstrap .navbar-fixed-top .navbar-inner,
  .bootstrap .navbar-fixed-bottom .navbar-inner {
    padding-left: 0;
    padding-right: 0; }
  .bootstrap .navbar-fixed-top .container,
  .bootstrap .navbar-fixed-bottom .container {
    width: 960px; }
  .bootstrap .navbar-fixed-top {
    top: 0; }
  .bootstrap .navbar-fixed-bottom {
    bottom: 0; }
  .bootstrap .navbar .nav {
    position: relative;
    left: 0;
    display: block;
    float: left;
    margin: 0 10px 0 0; }
  .bootstrap .navbar .nav.pull-right {
    float: right; }
  .bootstrap .navbar .nav > li {
    display: block;
    float: left; }
  .bootstrap .navbar .nav > li > a {
    float: none;
    padding: 0 10px;
    font-size: 11px;
    line-height: 30px;
    color: #eeeeee;
    text-decoration: none;
    text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25); }
  .bootstrap .navbar .btn {
    display: inline-block;
    padding: 4px 10px 4px;
    margin: 0px 5px 1px;
    line-height: 20px; }
  .bootstrap .navbar .btn-group {
    margin: 0;
    padding: 0px 5px 1px; }
  .bootstrap .navbar .nav > li > a:hover {
    background-color: transparent;
    color: #ffcc20;
    text-decoration: none; }
  .bootstrap .navbar .nav .active > a,
  .bootstrap .navbar .nav .active > a:hover {
    color: #222222;
    text-decoration: none;
    background-color: #ffcc20; }
  .bootstrap .navbar .divider-vertical {
    height: 30px;
    width: 1px;
    margin: 0 9px;
    overflow: hidden;
    background-color: #222222;
    border-right: 1px solid #555555; }
  .bootstrap .navbar .nav.pull-right {
    margin-left: 10px;
    margin-right: 0; }
  .bootstrap .navbar .btn-navbar {
    display: none;
    float: right;
    padding: 7px 10px;
    margin-left: 5px;
    margin-right: 5px;
    background-color: #404040;
    background-image: -moz-linear-gradient(top, #555555, #222222);
    background-image: -ms-linear-gradient(top, #555555, #222222);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#555555), to(#222222));
    background-image: -webkit-linear-gradient(top, #555555, #222222);
    background-image: -o-linear-gradient(top, #555555, #222222);
    background-image: linear-gradient(top, #555555, #222222);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#525252', endColorstr='#1f1f1f', GradientType=0);
    border-color: #222222 #222222 black;
    border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
    *background-color: #222222;
    /* Darken IE7 buttons by default so they stand out more given they won't have borders */
    filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
    -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.075);
    -moz-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.075);
    box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.075); }
    .bootstrap .navbar .btn-navbar:hover, .bootstrap .navbar .btn-navbar:active, .bootstrap .navbar .btn-navbar.active, .bootstrap .navbar .btn-navbar.disabled, .bootstrap .navbar .btn-navbar[disabled] {
      background-color: #222222;
      *background-color: #151515; }
    .bootstrap .navbar .btn-navbar:active, .bootstrap .navbar .btn-navbar.active {
      background-color: #090909 \9; }
  .bootstrap .navbar .btn-navbar .icon-bar {
    display: block;
    width: 18px;
    height: 2px;
    background-color: #f5f5f5;
    -webkit-border-radius: 1px;
    -moz-border-radius: 1px;
    border-radius: 1px;
    -webkit-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    -moz-box-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
    box-shadow: 0 1px 0 rgba(0, 0, 0, 0.25); }
  .bootstrap .btn-navbar .icon-bar + .icon-bar {
    margin-top: 3px; }
  .bootstrap .navbar .dropdown-menu:before {
    content: '';
    display: inline-block;
    border-left: 7px solid transparent;
    border-right: 7px solid transparent;
    border-bottom: 7px solid #ccc;
    border-bottom-color: rgba(0, 0, 0, 0.2);
    position: absolute;
    top: -7px;
    left: 9px; }
  .bootstrap .navbar .dropdown-menu:after {
    content: '';
    display: inline-block;
    border-left: 6px solid transparent;
    border-right: 6px solid transparent;
    border-bottom: 6px solid white;
    position: absolute;
    top: -6px;
    left: 10px; }
  .bootstrap .navbar-fixed-bottom .dropdown-menu:before {
    border-top: 7px solid #ccc;
    border-top-color: rgba(0, 0, 0, 0.2);
    border-bottom: 0;
    bottom: -7px;
    top: auto; }
  .bootstrap .navbar-fixed-bottom .dropdown-menu:after {
    border-top: 6px solid white;
    border-bottom: 0;
    bottom: -6px;
    top: auto; }
  .bootstrap .navbar .nav li.dropdown .dropdown-toggle .caret,
  .bootstrap .navbar .nav li.dropdown.open .caret {
    border-top-color: white;
    border-bottom-color: white; }
  .bootstrap .navbar .nav li.dropdown.active .caret {
    opacity: 1;
    filter: alpha(opacity=100); }
  .bootstrap .navbar .nav li.dropdown.open > .dropdown-toggle,
  .bootstrap .navbar .nav li.dropdown.active > .dropdown-toggle,
  .bootstrap .navbar .nav li.dropdown.open.active > .dropdown-toggle {
    background-color: transparent; }
  .bootstrap .navbar .nav li.dropdown.active > .dropdown-toggle:hover {
    color: white; }
  .bootstrap .navbar .pull-right .dropdown-menu,
  .bootstrap .navbar .dropdown-menu.pull-right {
    left: auto;
    right: 0; }
    .bootstrap .navbar .pull-right .dropdown-menu:before,
    .bootstrap .navbar .dropdown-menu.pull-right:before {
      left: auto;
      right: 12px; }
    .bootstrap .navbar .pull-right .dropdown-menu:after,
    .bootstrap .navbar .dropdown-menu.pull-right:after {
      left: auto;
      right: 13px; }
  .bootstrap .breadcrumb {
    font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
    font-size: 13px;
    padding: 7px 14px;
    margin: 0 0 20px;
    list-style: none;
    background-color: #fbfbfb;
    background-image: -moz-linear-gradient(top, white, whitesmoke);
    background-image: -ms-linear-gradient(top, white, whitesmoke);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(white), to(whitesmoke));
    background-image: -webkit-linear-gradient(top, white, whitesmoke);
    background-image: -o-linear-gradient(top, white, whitesmoke);
    background-image: linear-gradient(top, white, whitesmoke);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fcfcfc', endColorstr='#f2f2f2', GradientType=0);
    border: 1px solid #ddd;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
    -webkit-box-shadow: inset 0 1px 0 white;
    -moz-box-shadow: inset 0 1px 0 white;
    box-shadow: inset 0 1px 0 white; }
    .bootstrap .breadcrumb li {
      display: inline-block;
      *display: inline;
      *zoom: 1;
      text-shadow: 0 1px 0 white; }
    .bootstrap .breadcrumb .divider {
      padding: 0 5px;
      color: #999999; }
    .bootstrap .breadcrumb .active a {
      color: #333333; }
  .bootstrap .pagination {
    height: 40px;
    margin: 20px 0; }
  .bootstrap .pagination ul {
    display: inline-block;
    *display: inline;
    *zoom: 1;
    margin-left: 0;
    margin-bottom: 0;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
    -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
    -moz-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
    box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05); }
  .bootstrap .pagination li {
    display: inline; }
  .bootstrap .pagination a {
    float: left;
    padding: 0 14px;
    line-height: 38px;
    text-decoration: none;
    border: 1px solid #ddd;
    border-left-width: 0; }
  .bootstrap .pagination a:hover,
  .bootstrap .pagination .active a {
    background-color: #f5f5f5; }
  .bootstrap .pagination .active a {
    color: #999999;
    cursor: default; }
  .bootstrap .pagination .disabled span,
  .bootstrap .pagination .disabled a,
  .bootstrap .pagination .disabled a:hover {
    color: #999999;
    background-color: transparent;
    cursor: default; }
  .bootstrap .pagination li:first-child a {
    border-left-width: 1px;
    -webkit-border-radius: 3px 0 0 3px;
    -moz-border-radius: 3px 0 0 3px;
    border-radius: 3px 0 0 3px; }
  .bootstrap .pagination li:last-child a {
    -webkit-border-radius: 0 3px 3px 0;
    -moz-border-radius: 0 3px 3px 0;
    border-radius: 0 3px 3px 0; }
  .bootstrap .pagination-centered {
    text-align: center; }
  .bootstrap .pagination-right {
    text-align: right; }
  .bootstrap .pager {
    margin-left: 0;
    margin-bottom: 20px;
    list-style: none;
    text-align: center;
    *zoom: 1; }
    .bootstrap .pager:before, .bootstrap .pager:after {
      display: table;
      content: ""; }
    .bootstrap .pager:after {
      clear: both; }
  .bootstrap .pager li {
    display: inline; }
  .bootstrap .pager a {
    display: inline-block;
    padding: 5px 14px;
    background-color: #fff;
    border: 1px solid #ddd;
    -webkit-border-radius: 15px;
    -moz-border-radius: 15px;
    border-radius: 15px; }
  .bootstrap .pager a:hover {
    text-decoration: none;
    background-color: #f5f5f5; }
  .bootstrap .pager .next a {
    float: right; }
  .bootstrap .pager .previous a {
    float: left; }
  .bootstrap .pager .disabled a,
  .bootstrap .pager .disabled a:hover {
    color: #999999;
    background-color: #fff;
    cursor: default; }
  .bootstrap .modal-open .dropdown-menu {
    z-index: 2050; }
  .bootstrap .modal-open .dropdown.open {
    *z-index: 2050; }
  .bootstrap .modal-open .popover {
    z-index: 2060; }
  .bootstrap .modal-open .tooltip {
    z-index: 2070; }
  .bootstrap .modal-backdrop {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 1040;
    background-color: black; }
    .bootstrap .modal-backdrop.fade {
      opacity: 0; }
  .bootstrap .modal-backdrop,
  .bootstrap .modal-backdrop.fade.in {
    opacity: 0.8;
    filter: alpha(opacity=80); }
  .bootstrap .modal {
    position: fixed;
    top: 50%;
    left: 50%;
    z-index: 1050;
    overflow: auto;
    width: 560px;
    margin: -250px 0 0 -280px;
    background-color: white;
    border: 1px solid #999;
    border: 1px solid rgba(0, 0, 0, 0.3);
    *border: 1px solid #999;
    /* IE6-7 */
    -webkit-border-radius: 6px;
    -moz-border-radius: 6px;
    border-radius: 6px;
    -webkit-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    -webkit-background-clip: padding-box;
    -moz-background-clip: padding-box;
    background-clip: padding-box; }
    .bootstrap .modal.fade {
      -webkit-transition: opacity 0.3s linear, top 0.3s ease-out;
      -moz-transition: opacity 0.3s linear, top 0.3s ease-out;
      -ms-transition: opacity 0.3s linear, top 0.3s ease-out;
      -o-transition: opacity 0.3s linear, top 0.3s ease-out;
      transition: opacity 0.3s linear, top 0.3s ease-out;
      top: -25%; }
    .bootstrap .modal.fade.in {
      top: 50%; }
  .bootstrap .modal-header {
    padding: 9px 15px;
    border-bottom: 1px solid #eee; }
    .bootstrap .modal-header .close {
      margin-top: 2px; }
  .bootstrap .modal-body {
    overflow-y: auto;
    max-height: 400px;
    padding: 15px; }
  .bootstrap .modal-form {
    margin-bottom: 0; }
  .bootstrap .modal-footer {
    padding: 14px 15px 15px;
    margin-bottom: 0;
    text-align: right;
    background-color: #f5f5f5;
    border-top: 1px solid #ddd;
    -webkit-border-radius: 0 0 6px 6px;
    -moz-border-radius: 0 0 6px 6px;
    border-radius: 0 0 6px 6px;
    -webkit-box-shadow: inset 0 1px 0 white;
    -moz-box-shadow: inset 0 1px 0 white;
    box-shadow: inset 0 1px 0 white;
    *zoom: 1; }
    .bootstrap .modal-footer:before, .bootstrap .modal-footer:after {
      display: table;
      content: ""; }
    .bootstrap .modal-footer:after {
      clear: both; }
    .bootstrap .modal-footer .btn + .btn {
      margin-left: 5px;
      margin-bottom: 0; }
    .bootstrap .modal-footer .btn-group .btn + .btn {
      margin-left: -1px; }
  .bootstrap .popover {
    position: absolute;
    top: 0;
    left: 0;
    z-index: 1010;
    display: none;
    padding: 5px; }
    .bootstrap .popover.top {
      margin-top: -5px; }
    .bootstrap .popover.right {
      margin-left: 5px; }
    .bootstrap .popover.bottom {
      margin-top: 5px; }
    .bootstrap .popover.left {
      margin-left: -5px; }
    .bootstrap .popover.top .arrow {
      bottom: 0;
      left: 50%;
      margin-left: -5px;
      border-left: 5px solid transparent;
      border-right: 5px solid transparent;
      border-top: 5px solid black; }
    .bootstrap .popover.right .arrow {
      top: 50%;
      left: 0;
      margin-top: -5px;
      border-top: 5px solid transparent;
      border-bottom: 5px solid transparent;
      border-right: 5px solid black; }
    .bootstrap .popover.bottom .arrow {
      top: 0;
      left: 50%;
      margin-left: -5px;
      border-left: 5px solid transparent;
      border-right: 5px solid transparent;
      border-bottom: 5px solid black; }
    .bootstrap .popover.left .arrow {
      top: 50%;
      right: 0;
      margin-top: -5px;
      border-top: 5px solid transparent;
      border-bottom: 5px solid transparent;
      border-left: 5px solid black; }
    .bootstrap .popover .arrow {
      position: absolute;
      width: 0;
      height: 0; }
  .bootstrap .popover-inner {
    padding: 3px;
    width: 280px;
    overflow: hidden;
    background: black;
    background: rgba(0, 0, 0, 0.8);
    -webkit-border-radius: 6px;
    -moz-border-radius: 6px;
    border-radius: 6px;
    -webkit-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3); }
  .bootstrap .popover-title {
    padding: 9px 15px;
    line-height: 1;
    background-color: #f5f5f5;
    border-bottom: 1px solid #eee;
    -webkit-border-radius: 3px 3px 0 0;
    -moz-border-radius: 3px 3px 0 0;
    border-radius: 3px 3px 0 0; }
  .bootstrap .popover-content {
    padding: 14px;
    background-color: white;
    -webkit-border-radius: 0 0 3px 3px;
    -moz-border-radius: 0 0 3px 3px;
    border-radius: 0 0 3px 3px;
    -webkit-background-clip: padding-box;
    -moz-background-clip: padding-box;
    background-clip: padding-box; }
    .bootstrap .popover-content p, .bootstrap .popover-content ul, .bootstrap .popover-content ol {
      margin-bottom: 0; }
  .bootstrap .thumbnails {
    margin-left: -12px;
    list-style: none;
    *zoom: 1; }
    .bootstrap .thumbnails:before, .bootstrap .thumbnails:after {
      display: table;
      content: ""; }
    .bootstrap .thumbnails:after {
      clear: both; }
  .bootstrap .row-fluid .thumbnails {
    margin-left: 0; }
  .bootstrap .thumbnails > li {
    float: left;
    margin-bottom: 20px;
    margin-left: 12px; }
  .bootstrap .thumbnail {
    display: block;
    padding: 4px;
    line-height: 1;
    border: 1px solid #ddd;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.075);
    -moz-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.075); }
  .bootstrap a.thumbnail:hover {
    border-color: #008990;
    -webkit-box-shadow: 0 1px 4px rgba(0, 105, 214, 0.25);
    -moz-box-shadow: 0 1px 4px rgba(0, 105, 214, 0.25);
    box-shadow: 0 1px 4px rgba(0, 105, 214, 0.25); }
  .bootstrap .thumbnail > img {
    display: block;
    max-width: 100%;
    margin-left: auto;
    margin-right: auto; }
  .bootstrap .thumbnail .caption {
    padding: 9px; }
  .bootstrap .label,
  .bootstrap .badge {
    font-size: 12.69px;
    font-weight: bold;
    line-height: 14px;
    color: white;
    vertical-align: baseline;
    white-space: nowrap;
    text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
    background-color: #999999; }
  .bootstrap .label {
    padding: 1px 4px 2px;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px; }
  .bootstrap .badge {
    padding: 1px 9px 2px;
    -webkit-border-radius: 9px;
    -moz-border-radius: 9px;
    border-radius: 9px; }
  .bootstrap a.label:hover, .bootstrap a.badge:hover {
    color: white;
    text-decoration: none;
    cursor: pointer; }
  .bootstrap .label-important, .bootstrap .badge-important {
    background-color: #b94a48; }
  .bootstrap .label-important[href], .bootstrap .badge-important[href] {
    background-color: #953b39; }
  .bootstrap .label-warning, .bootstrap .badge-warning {
    background-color: #f89406; }
  .bootstrap .label-warning[href], .bootstrap .badge-warning[href] {
    background-color: #c67605; }
  .bootstrap .label-success, .bootstrap .badge-success {
    background-color: #468847; }
  .bootstrap .label-success[href], .bootstrap .badge-success[href] {
    background-color: #356635; }
  .bootstrap .label-info, .bootstrap .badge-info {
    background-color: #3a87ad; }
  .bootstrap .label-info[href], .bootstrap .badge-info[href] {
    background-color: #2d6987; }
  .bootstrap .label-inverse, .bootstrap .badge-inverse {
    background-color: #333333; }
  .bootstrap .label-inverse[href], .bootstrap .badge-inverse[href] {
    background-color: #1a1a1a; }
  .bootstrap .progress {
    overflow: hidden;
    height: 18px;
    margin-bottom: 18px;
    background-color: #f6f6f6;
    background-image: -moz-linear-gradient(top, whitesmoke, #f9f9f9);
    background-image: -ms-linear-gradient(top, whitesmoke, #f9f9f9);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(whitesmoke), to(#f9f9f9));
    background-image: -webkit-linear-gradient(top, whitesmoke, #f9f9f9);
    background-image: -o-linear-gradient(top, whitesmoke, #f9f9f9);
    background-image: linear-gradient(top, whitesmoke, #f9f9f9);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#f2f2f2', endColorstr='#f6f6f6', GradientType=0);
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px; }
  .bootstrap .progress .bar {
    width: 0%;
    height: 18px;
    color: white;
    font-size: 12px;
    text-align: center;
    text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
    background-color: #0d90d1;
    background-image: -moz-linear-gradient(top, #149bdf, #0480be);
    background-image: -ms-linear-gradient(top, #149bdf, #0480be);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#149bdf), to(#0480be));
    background-image: -webkit-linear-gradient(top, #149bdf, #0480be);
    background-image: -o-linear-gradient(top, #149bdf, #0480be);
    background-image: linear-gradient(top, #149bdf, #0480be);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#1498da', endColorstr='#047db9', GradientType=0);
    -webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
    -moz-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
    box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    -ms-box-sizing: border-box;
    box-sizing: border-box;
    -webkit-transition: width 0.6s ease;
    -moz-transition: width 0.6s ease;
    -ms-transition: width 0.6s ease;
    -o-transition: width 0.6s ease;
    transition: width 0.6s ease; }
  .bootstrap .progress-striped .bar {
    background-color: #149bdf;
    background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
    background-image: -webkit-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: -moz-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: -ms-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: -o-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    -webkit-background-size: 40px 40px;
    -moz-background-size: 40px 40px;
    -o-background-size: 40px 40px;
    background-size: 40px 40px; }
  .bootstrap .progress.active .bar {
    -webkit-animation: progress-bar-stripes 2s linear infinite;
    -moz-animation: progress-bar-stripes 2s linear infinite;
    -ms-animation: progress-bar-stripes 2s linear infinite;
    -o-animation: progress-bar-stripes 2s linear infinite;
    animation: progress-bar-stripes 2s linear infinite; }
  .bootstrap .progress-danger .bar {
    background-color: #dd514b;
    background-image: -moz-linear-gradient(top, #ee5f5b, #c43c35);
    background-image: -ms-linear-gradient(top, #ee5f5b, #c43c35);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ee5f5b), to(#c43c35));
    background-image: -webkit-linear-gradient(top, #ee5f5b, #c43c35);
    background-image: -o-linear-gradient(top, #ee5f5b, #c43c35);
    background-image: linear-gradient(top, #ee5f5b, #c43c35);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ee5a56', endColorstr='#c03b34', GradientType=0); }
  .bootstrap .progress-danger.progress-striped .bar {
    background-color: #ee5f5b;
    background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
    background-image: -webkit-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: -moz-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: -ms-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: -o-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }
  .bootstrap .progress-success .bar {
    background-color: #5db95d;
    background-image: -moz-linear-gradient(top, #62c462, #57a957);
    background-image: -ms-linear-gradient(top, #62c462, #57a957);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#62c462), to(#57a957));
    background-image: -webkit-linear-gradient(top, #62c462, #57a957);
    background-image: -o-linear-gradient(top, #62c462, #57a957);
    background-image: linear-gradient(top, #62c462, #57a957);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#5ec35e', endColorstr='#55a655', GradientType=0); }
  .bootstrap .progress-success.progress-striped .bar {
    background-color: #62c462;
    background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
    background-image: -webkit-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: -moz-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: -ms-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: -o-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }
  .bootstrap .progress-info .bar {
    background-color: #4bb1cf;
    background-image: -moz-linear-gradient(top, #5bc0de, #339bb9);
    background-image: -ms-linear-gradient(top, #5bc0de, #339bb9);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#5bc0de), to(#339bb9));
    background-image: -webkit-linear-gradient(top, #5bc0de, #339bb9);
    background-image: -o-linear-gradient(top, #5bc0de, #339bb9);
    background-image: linear-gradient(top, #5bc0de, #339bb9);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#57bedd', endColorstr='#3298b5', GradientType=0); }
  .bootstrap .progress-info.progress-striped .bar {
    background-color: #5bc0de;
    background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
    background-image: -webkit-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: -moz-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: -ms-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: -o-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }
  .bootstrap .progress-warning .bar {
    background-color: #f9a732;
    background-image: -moz-linear-gradient(top, #fbb450, #f89406);
    background-image: -ms-linear-gradient(top, #fbb450, #f89406);
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#fbb450), to(#f89406));
    background-image: -webkit-linear-gradient(top, #fbb450, #f89406);
    background-image: -o-linear-gradient(top, #fbb450, #f89406);
    background-image: linear-gradient(top, #fbb450, #f89406);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fbb24b', endColorstr='#f39106', GradientType=0); }
  .bootstrap .progress-warning.progress-striped .bar {
    background-color: #fbb450;
    background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
    background-image: -webkit-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: -moz-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: -ms-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: -o-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }
  .bootstrap .accordion {
    margin-bottom: 20px; }
  .bootstrap .accordion-group {
    margin-bottom: 2px;
    border: 1px solid #e5e5e5;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px; }
  .bootstrap .accordion-heading {
    border-bottom: 0; }
  .bootstrap .accordion-heading .accordion-toggle {
    display: block;
    padding: 8px 15px; }
  .bootstrap .accordion-toggle {
    cursor: pointer; }
  .bootstrap .accordion-inner {
    padding: 9px 15px;
    border-top: 1px solid #e5e5e5; }
  .bootstrap .carousel {
    position: relative;
    margin-bottom: 20px;
    line-height: 1; }
  .bootstrap .carousel-inner {
    overflow: hidden;
    width: 100%;
    position: relative; }
  .bootstrap .carousel .item {
    display: none;
    position: relative;
    -webkit-transition: 0.6s ease-in-out left;
    -moz-transition: 0.6s ease-in-out left;
    -ms-transition: 0.6s ease-in-out left;
    -o-transition: 0.6s ease-in-out left;
    transition: 0.6s ease-in-out left; }
  .bootstrap .carousel .item > img {
    display: block;
    line-height: 1; }
  .bootstrap .carousel .active,
  .bootstrap .carousel .next,
  .bootstrap .carousel .prev {
    display: block; }
  .bootstrap .carousel .active {
    left: 0; }
  .bootstrap .carousel .next,
  .bootstrap .carousel .prev {
    position: absolute;
    top: 0;
    width: 100%; }
  .bootstrap .carousel .next {
    left: 100%; }
  .bootstrap .carousel .prev {
    left: -100%; }
  .bootstrap .carousel .next.left,
  .bootstrap .carousel .prev.right {
    left: 0; }
  .bootstrap .carousel .active.left {
    left: -100%; }
  .bootstrap .carousel .active.right {
    left: 100%; }
  .bootstrap .carousel-control {
    position: absolute;
    top: 40%;
    left: 15px;
    width: 40px;
    height: 40px;
    margin-top: -20px;
    font-size: 60px;
    font-weight: 100;
    line-height: 30px;
    color: white;
    text-align: center;
    background: #222222;
    border: 3px solid white;
    -webkit-border-radius: 23px;
    -moz-border-radius: 23px;
    border-radius: 23px;
    opacity: 0.5;
    filter: alpha(opacity=50); }
    .bootstrap .carousel-control.right {
      left: auto;
      right: 15px; }
    .bootstrap .carousel-control:hover {
      color: white;
      text-decoration: none;
      opacity: 0.9;
      filter: alpha(opacity=90); }
  .bootstrap .carousel-caption {
    position: absolute;
    left: 0;
    right: 0;
    bottom: 0;
    padding: 10px 15px 5px;
    background: #333333;
    background: rgba(0, 0, 0, 0.75); }
  .bootstrap .carousel-caption h4,
  .bootstrap .carousel-caption p {
    color: white; }
  .bootstrap .hero-unit {
    padding: 60px;
    margin-bottom: 30px;
    background-color: #eeeeee;
    -webkit-border-radius: 6px;
    -moz-border-radius: 6px;
    border-radius: 6px; }
    .bootstrap .hero-unit h1 {
      margin-bottom: 0;
      font-size: 60px;
      line-height: 1;
      color: inherit;
      letter-spacing: -1px; }
    .bootstrap .hero-unit p {
      font-size: 18px;
      font-weight: 200;
      line-height: 30px;
      color: inherit; }
  .bootstrap .pull-right {
    float: right; }
  .bootstrap .pull-left {
    float: left; }
  .bootstrap .hide {
    display: none; }
  .bootstrap .show {
    display: block; }
  .bootstrap .invisible {
    visibility: hidden; }

.tooltip {
  position: absolute;
  z-index: 1020;
  display: block;
  visibility: visible;
  padding: 5px;
  font-size: 13px;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  opacity: 0;
  filter: alpha(opacity=0); }
  .tooltip.in {
    opacity: 0.8;
    filter: alpha(opacity=80); }
  .tooltip.top {
    margin-top: -2px; }
  .tooltip.right {
    margin-left: 2px; }
  .tooltip.bottom {
    margin-top: 2px; }
  .tooltip.left {
    margin-left: -2px; }
  .tooltip.top .tooltip-arrow {
    bottom: 0;
    left: 50%;
    margin-left: -5px;
    border-left: 5px solid transparent;
    border-right: 5px solid transparent;
    border-top: 5px solid black; }
  .tooltip.left .tooltip-arrow {
    top: 50%;
    right: 0;
    margin-top: -5px;
    border-top: 5px solid transparent;
    border-bottom: 5px solid transparent;
    border-left: 5px solid black; }
  .tooltip.bottom .tooltip-arrow {
    top: 0;
    left: 50%;
    margin-left: -5px;
    border-left: 5px solid transparent;
    border-right: 5px solid transparent;
    border-bottom: 5px solid black; }
  .tooltip.right .tooltip-arrow {
    top: 50%;
    left: 0;
    margin-top: -5px;
    border-top: 5px solid transparent;
    border-bottom: 5px solid transparent;
    border-right: 5px solid black; }

.tooltip-inner {
  max-width: 200px;
  padding: 3px 8px;
  color: white;
  line-height: 20px;
  text-align: center;
  text-decoration: none;
  background-color: black;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px; }

.tooltip-arrow {
  position: absolute;
  width: 0;
  height: 0; }
