{% load humanize %}
<table class="data-source chart-data table table-striped table-condensed">
  <thead>
    <tr>
      <th class="span1">Year</th>
      <th class="span3" data-tablebars=1>Applicants</th>
      <th class="span3" data-tablebars=1>Admitted</th>
      <th class="span3" data-tablebars=1>Enrolled</th>
    </tr>
  </thead>
  <tbody>
    {% for object in object_list %}
      {% if object.number_of_applicants %}
        <tr>
          <td data-value="{{ object.year }}">{{ object.year }}</td>
          <td data-value="{{ object.number_of_applicants }}">
            {{ object.number_of_applicants|intcomma }}
          </td>
          <td data-value="{{ object.number_admitted }}">
            {{ object.number_admitted|intcomma }}
            <small>({{ object.percent_of_applicants_admitted }}%)</small>
          </td>
          <td data-value="{{ object.number_admitted_who_enrolled }}">
            {{ object.number_admitted_who_enrolled|intcomma }}
            <small>({{ object.percent_of_admitted_who_enrolled }}%)</small>
          </td>
        </tr>
      {% endif %}
    {% endfor %}
  </tbody>
</table>
