{% load instachart %}
<table>
  {% block thead %}
  <thead>
    <tr>
      {% for cell in chart_header %}
        {{ cell.as_th|safe }}
      {% endfor %}
    </tr>
  </thead>
  {% endblock %}
  {% block tbody %}
  <tbody>
    {% for row in object_list %}
      <tr>
        {% for cell in row|chart_set %}
          {{ cell.as_td|safe }}
        {% endfor %}
      </tr>
    {% endfor %}
  </tbody>
  {% endblock %}
</table>
