/* Texas Higher Ed App CSS assumes bootstrap
*/
.chart-data { font-family: sans-serif; font-size: 12px; }

.wide-chart-wrapper { overflow-x: auto; }
.wide-chart-wrapper > .chart-data { margin-left: 10em; }
.wide-chart-wrapper tr > *:first-child { left: 0; margin-top: -1px; position: absolute; white-space: nowrap; width: 10em; }
.wide-chart-wrapper tr:nth-child(2n) > *:first-child { background-color: white; }

.chart-viz { height: 300px; }
.chart-viz.loading { background: url(../../../common/images/ajax_bar.gif) no-repeat scroll 50% 50% #eee; }
.chart-viz .axis { font-family: sans-serif; font-size: 12px; }
.chart-viz .axis text { fill: #333; }

.chart-help .item + .item { margin-top: 0.3em; }

svg .axis { shape-rendering: crispEdges; }
svg .axis .domain { display: none; }
svg .y.axis line { stroke: #000; }
svg .sealevel { stroke: rgba(30, 30, 80, 0.4); }
svg .demarcation { stroke: #444; }

.chart-legend { font-family: sans-serif; font-size: 12px; }
.chart-legend ul { list-style: none; margin: 0; }
.chart-legend .legend-key { margin-right: 5px; }

.legend li.inactive > a { cursor: inherit; }

.bootstrap .legend li.inactive > a:hover { background-color: transparent; }

.bootstrap .legend .nav-pills > li > a { padding: 6px 12px; }

.legend a, legend a:hover { color: inherit; }

#mapCanvas { background-color: #C2D8D1; height: 650px; width: 100%; }

#mapPopupContainer { font-family: "Helvetica Neue", Arial, sans-serif; text-align: center; font-size: 14px; position: absolute; top: 10px; right: 10px; z-index: 1002; background-color: #FFFFFF; padding: 8px; display: none; }

#mapPopupContainer h2 { font-size: 1em; margin: 0; padding: 0; }

#mapPopupContainer h4 { font-size: .85em; margin: 0; padding: 0; }

.shadow { -moz-box-shadow: 2px 2px 5px 1px #444444; -webkit-box-shadow: 2px 2px 5px 1px #444444; box-shadow: 1px 1px 4px 1px #444444; }

@media print { #site_roofline, #greeting { display: none; }
  .breadcrumb .caret, .breadcrumb .navbar-search { display: none; } }
#intro p { line-height: 1.35; margin: 0.5em 0; }

#pricetrends .chart-data tbody td { text-align: right; }
#pricetrends .chart-data .dollar { color: #666; }
#pricetrends .chart-data .currency { margin-right: 14px; }

h2 > .page-anchor, h3 > .page-anchor { visibility: hidden; }
h2:hover > .page-anchor, h3:hover > .page-anchor { visibility: visible; }

td.align-right { text-align: right; }
td.align-right .ui-tablebar { right: 0; }

th aside { display: inline-block !important; width: 10%; }

.ui-tablebar { color: #333; background: #DACD99; }

.onion-item, .onion-legend-item { display: inline-block; text-align: center; width: 100px; }

.nav-pills .onion-legend-item { float: none; }

.funnel { width: 100%; }

.funnel .bar { background: #0074CC; margin: 0 auto; overflow: hidden; text-indent: 110%; }

.ui-onion-item-active .bar { outline: 1px solid black; background: transparent; }

.sentences { font-family: Helvetica, Arial, sans-serif; font-size: 0.9em; }

.higher-ed .landing { padding-top: 0.75em; font-family: Helvetica, Arial, sans-serif; }
.higher-ed .landing .map-container { position: relative; }
.higher-ed .landing .map-container button { position: absolute; left: 33%; width: 33%; display: block; z-index: 1000; }
.higher-ed .presented_by { font-family: Georgia, "Times New Roman", Times, serif; font-size: 12.75px; text-align: center; }
.higher-ed .presented_by p { margin-bottom: 0; white-space: nowrap; }
.higher-ed .presented_by .logo { border-width: 1px 0px; border-style: solid; padding: 20px 0 20px; border-color: rgba(0, 0, 0, 0.1); margin: 1em 0; }
.higher-ed .presented_by img { display: block; margin: 0 auto; width: 202px; }
.higher-ed table.data-source { display: none; }
.higher-ed .admissions tbody td small { display: block; }

.data-app .app-header h1 { font-family: "freight-sans-pro-n9", "freight-sans-pro", sans-serif; font-weight: 900; font-size: 2.75em; text-transform: uppercase; height: 60px; }
.data-app .app-header h1 img { margin-right: 5px; }
.data-app .app-header h1 a { color: #222; text-decoration: none; }
.data-app .app-header h1 small { font-family: Helvetica, Arial, sans-serif; display: block; font-size: 0.45em; text-transform: none; margin-left: 3.65em; }
.data-app .page-header { font-family: Helvetica, Arial, sans-serif; border-bottom-color: #eee; }
.data-app h1, .data-app h2, .data-app h3 { font-family: Helvetica, Arial, sans-serif; }
.data-app .rollup { font-family: Helvetica, Arial, sans-serif; font-size: 20px; }
.data-app .input-append .add-on:hover { cursor: pointer; }
.data-app #attribution { font-family: Helvetica, Arial, sans-serif; font-size: 90%; margin-top: 2em; margin-bottom: -2em; }
.data-app #attribution i { height: 1.2em; vertical-align: middle; }

.bootstrap .well { background-color: whiteSmoke; }

dfn { font-weight: inherit; border-bottom: 1px dotted #222; }
dfn:hover { cursor: help; }

.bootstrap .breadcrumb .btn-group > .dropdown-toggle { padding-left: 0; padding-right: 0; }
.bootstrap .breadcrumb .btn-group.open .dropdown-toggle { box-shadow: none; }
.bootstrap .breadcrumb .dropdown-menu .active a { color: white; }
.bootstrap .breadcrumb .dropdown-menu li { display: block; }
.bootstrap .breadcrumb .navbar-search { margin-top: -1px; }

.no-js .requires-js { display: none !important; }

.no-svg .requires-svg { display: none; }

/*# sourceMappingURL=tx_highered.css.map */
