{% if object.address or object.city or object.zip_code or object.phone or object.url %}
<div class="well well-small">
  <div>
    {% if object.address %}{{ object.address }}<br>{% endif %}
    {% if object.city %}{{ object.city }}, Texas{% endif %}
    {{ object.zip_code }}
  </div>

  <div class="phone">
    {{ object.phone }}
  </div>

  {% if object.url %}
  <div class="website">
    <a href="http://{{ object.url }}">{{ object.url }}</a>
  </div>
  {% endif %}

</div>
{% endif %}
