<tbody data-pk="{{ object.pk }}">
  <tr>
    <td>{{ object.display_year }}</td>
    <td>
      {{ object.sat_verbal_range }}
    </td>
    <td>
      {{ object.sat_math_range }}
    </td>
    <td>
      {{ object.sat_writing_range|default:"N/A" }}
    </td>
  </tr>
  {% comment %}
  <tr style="display: none;">
    <td>
      <div class=paper style="position: relative;">
        {% if object.act_english_25th_percentile %}
          <div class="clearfix" style="margin-bottom: 2px;">
            <span class="label pull-left">{{ object.act_english_25th_percentile }}</span>
            <span class="label pull-right">{{ object.act_english_75th_percentile }}</span>
          </div>
        {% endif %}
        {% if object.act_math_25th_percentile %}
          <div class="clearfix" style="margin-bottom: 2px;">
            <span class="label pull-left">{{ object.act_math_25th_percentile }}</span>
            <span class="label pull-right">{{ object.act_math_75th_percentile }}</span>
          </div>
        {% endif %}
        {% if object.act_writing_25th_percentile %}
          <div class="clearfix" style="margin-bottom: 2px">
            <span class="label pull-left">{{ object.act_writing_25th_percentile }}</span>
            <span class="label pull-right">{{ object.act_writing_75th_percentile }}</span>
          </div>
        {% endif %}
        {% if object.act_composite_25th_percentile %}
          <div class="clearfix" style="margin-bottom: 2px;">
            <span class="label pull-left">{{ object.act_composite_25th_percentile }}</span>
            <span class="label pull-right">{{ object.act_composite_75th_percentile }}</span>
          </div>
        {% endif %}
      </div>
    </td>
  </tr>
  {% endcomment %}
</tbody>
