{% extends "layouts/base.html" %}
{% load static from staticfiles %}


{% block opengraph_meta %}{{ block.super }}
  <meta property="og:type" content="website">
  <meta property="og:image" content="{% static 'tx_highered/images/icon-opengraph.png' %}">
{% endblock %}


{% block extra_style %}{{ block.super }}
  <link rel="stylesheet" href="{% static 'tx_highered/vendor/bootstrap/css/ttstrap.css' %}">
  <link rel="stylesheet" href="{% static 'tx_highered/css/tx_highered.css' %}">
  <link rel="stylesheet" href="{% static 'tx_highered/css/jquery-ui-custom.css' %}">
{% endblock %}


{% block extra_head %}{{ block.super }}
  <script src="{% static 'vendor/modernizr/modernizr.min.js' %}"></script>
{% endblock %}


{% block body_class %}data-app higher-ed{% endblock %}


{# UGH #}
{% block content_class %}{{ block.super }} bootstrap{% endblock %}


{% block site_content %}
  <div id="highered-header" class="page-header app-header">
    {% block facebook_recommend %}
      {% comment %}
      TODO: Enable once on the Tribune
      <div class="pull-right fb-recommend">
        {% include "includes/facebook_like_sidebar.html" %}
      </div>
      {% endcomment %}
    {% endblock %}

    <h1>
      <img class="pull-left" src="{% static 'tx_highered/css/icon.png' %}" alt="">
      <a href="{% url 'tx_highered:home' %}">Higher Education Explorer</a>
      <small>The Texas Tribune's go-to source for higher education data</small>
    </h1>
  </div>

  {% block breadcrumb_base %}
    <ul class="breadcrumb">
      <li>
        <a href="{% url 'tx_highered:home' %}">Home</a>
        <span class="divider">/</span>
      </li>
      {% block breadcrumb_items %}{% endblock %}
      {% block breadcrumb_items_after %}{% endblock %}
    </ul>
  {% endblock %}

  {% block main_base %}
    {% block main %}{% endblock %}
  {% endblock %}
{% endblock site_content %}


{% block extra_script %}{{ block.super }}
  <script src="{% static 'tx_highered/js/trisim.js' %}"></script>
  <script src="{% static 'tx_highered/js/autocomplete.js' %}"></script>
  <script src="{% static 'd3/js/d3.v2.min.js' %}"></script>
{% endblock %}
